@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998 Cesar Miquel, Shawn T. Amundson, Mattias Grnlund
+ * Copyright (C) 1998 Cesar Miquel, Shawn T. Amundson, Mattias Grönlund
  * Copyright (C) 2000 Tony Gale
  *
  * This program is free software; you can redistribute it and/or modify
@@ -224,7 +224,7 @@ static void calendar_select_font( GtkWidget    *button,
 			     calendar->font_dialog);
   }
   window = calendar->font_dialog;
-  if (!GTK_WIDGET_VISIBLE (window))
+  if (!gtk_widget_get_visible (window))
     gtk_widget_show (window);
   else
     gtk_widget_destroy (window);
@@ -393,7 +393,7 @@ static void create_calendar( void )
 		    G_CALLBACK (gtk_main_quit),
 		    NULL);
   gtk_container_add (GTK_CONTAINER (bbox), button);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
   gtk_widget_grab_default (button);
 
   gtk_widget_show_all (window);
