@@ -33,6 +33,8 @@
 #include <gdk/gdkcairo.h>
 #include <gdk/gdkcolor.h>
 #include <gdk/gdkcursor.h>
+#include <gdk/gdkdevice.h>
+#include <gdk/gdkdevicemanager.h>
 #include <gdk/gdkdisplay.h>
 #include <gdk/gdkdisplaymanager.h>
 #include <gdk/gdkdnd.h>
@@ -66,6 +68,7 @@ G_BEGIN_DECLS
 /* Initialization, exit and events
  */
 #define	  GDK_PRIORITY_EVENTS		(G_PRIORITY_DEFAULT)
+void      gdk_enable_multidevice        (void);
 void 	  gdk_parse_args	   	(gint	   	*argc,
 					 gchar        ***argv);
 void 	  gdk_init		   	(gint	   	*argc,
@@ -75,9 +78,6 @@ gboolean  gdk_init_check   	        (gint	   	*argc,
 void gdk_add_option_entries_libgtk_only (GOptionGroup *group);
 void gdk_pre_parse_libgtk_only          (void);
 
-#ifndef GDK_DISABLE_DEPRECATED
-void  	  gdk_exit		   	(gint	    	 error_code);
-#endif /* GDK_DISABLE_DEPRECATED */
 gchar*	  gdk_set_locale	   	(void);
 
 G_CONST_RETURN char *gdk_get_program_class (void);
@@ -88,30 +88,10 @@ void                 gdk_set_program_class (const char *program_class);
 void      gdk_error_trap_push           (void);
 gint      gdk_error_trap_pop            (void);
 
-#ifndef GDK_DISABLE_DEPRECATED
-void	  gdk_set_use_xshm		(gboolean	 use_xshm);
-gboolean  gdk_get_use_xshm		(void);
-#endif /* GDK_DISABLE_DEPRECATED */
-
 gchar*	                  gdk_get_display		(void);
 G_CONST_RETURN gchar*	  gdk_get_display_arg_name	(void);
 
-#if !defined (GDK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION)
-/* Used by gtk_input_add_full () */
-gint gdk_input_add_full	  (gint		     source,
-			   GdkInputCondition condition,
-			   GdkInputFunction  function,
-			   gpointer	     data,
-			   GDestroyNotify    destroy);
-#endif /* !GDK_DISABLE_DEPRECATED || GTK_COMPILATION */
-#ifndef GDK_DISABLE_DEPRECATED
-gint gdk_input_add	  (gint		     source,
-			   GdkInputCondition condition,
-			   GdkInputFunction  function,
-			   gpointer	     data);
-void gdk_input_remove	  (gint		     tag);
-#endif /* GDK_DISABLE_DEPRECATED */
-
+#ifndef GDK_MULTIDEVICE_SAFE
 GdkGrabStatus gdk_pointer_grab       (GdkWindow    *window,
 				      gboolean      owner_events,
 				      GdkEventMask  event_mask,
@@ -121,18 +101,15 @@ GdkGrabStatus gdk_pointer_grab       (GdkWindow    *window,
 GdkGrabStatus gdk_keyboard_grab      (GdkWindow    *window,
 				      gboolean      owner_events,
 				      guint32       time_);
-
-gboolean gdk_pointer_grab_info_libgtk_only (GdkDisplay *display,
-					    GdkWindow **grab_window,
-					    gboolean   *owner_events);
-gboolean gdk_keyboard_grab_info_libgtk_only (GdkDisplay *display,
-					     GdkWindow **grab_window,
-					     gboolean   *owner_events);
+#endif /* GDK_MULTIDEVICE_SAFE */
 
 #ifndef GDK_MULTIHEAD_SAFE
+
+#ifndef GDK_MULTIDEVICE_SAFE
 void          gdk_pointer_ungrab     (guint32       time_);
 void          gdk_keyboard_ungrab    (guint32       time_);
 gboolean      gdk_pointer_is_grabbed (void);
+#endif /* GDK_MULTIDEVICE_SAFE */
 
 gint gdk_screen_width  (void) G_GNUC_CONST;
 gint gdk_screen_height (void) G_GNUC_CONST;
@@ -162,15 +139,6 @@ GType gdk_rectangle_get_type (void) G_GNUC_CONST;
 
 #define GDK_TYPE_RECTANGLE (gdk_rectangle_get_type ())
 
-/* Conversion functions between wide char and multibyte strings. 
- */
-#ifndef GDK_DISABLE_DEPRECATED
-gchar     *gdk_wcstombs          (const GdkWChar   *src);
-gint       gdk_mbstowcs          (GdkWChar         *dest,
-				  const gchar      *src,
-				  gint              dest_max);
-#endif
-
 /* Miscellaneous */
 #ifndef GDK_MULTIHEAD_SAFE
 gboolean gdk_event_send_client_message      (GdkEvent       *event,
@@ -195,26 +163,34 @@ GDKVAR GMutex *gdk_threads_mutex; /* private */
 GDKVAR GCallback gdk_threads_lock;
 GDKVAR GCallback gdk_threads_unlock;
 
-void     gdk_threads_enter                (void);
-void     gdk_threads_leave                (void);
-void     gdk_threads_init                 (void);
-void     gdk_threads_set_lock_functions   (GCallback enter_fn,
-					   GCallback leave_fn);
+void     gdk_threads_enter                    (void);
+void     gdk_threads_leave                    (void);
+void     gdk_threads_init                     (void);
+void     gdk_threads_set_lock_functions       (GCallback enter_fn,
+					       GCallback leave_fn);
 
-guint    gdk_threads_add_idle_full        (gint           priority,
-		                           GSourceFunc    function,
-		                           gpointer       data,
-		                           GDestroyNotify notify);
-guint    gdk_threads_add_idle             (GSourceFunc    function,
-		                           gpointer       data);
-guint    gdk_threads_add_timeout_full     (gint           priority,
-                                           guint          interval,
-                                           GSourceFunc    function,
-                                           gpointer       data,
-                                           GDestroyNotify notify);
-guint    gdk_threads_add_timeout          (guint          interval,
-                                           GSourceFunc    function,
-                                           gpointer       data);
+guint    gdk_threads_add_idle_full            (gint           priority,
+		                               GSourceFunc    function,
+		                               gpointer       data,
+		                               GDestroyNotify notify);
+guint    gdk_threads_add_idle                 (GSourceFunc    function,
+		                               gpointer       data);
+guint    gdk_threads_add_timeout_full         (gint           priority,
+                                               guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data,
+                                               GDestroyNotify notify);
+guint    gdk_threads_add_timeout              (guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data);
+guint    gdk_threads_add_timeout_seconds_full (gint           priority,
+                                               guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data,
+                                               GDestroyNotify notify);
+guint    gdk_threads_add_timeout_seconds      (guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data);
 
 #ifdef	G_THREADS_ENABLED
 #  define GDK_THREADS_ENTER()	G_STMT_START {	\
