@@ -94,51 +94,6 @@ gdk_drawable_init (GdkDrawable *drawable)
 /* Manipulation of drawables
  */
 
-/**
- * gdk_drawable_set_data:
- * @drawable: a #GdkDrawable
- * @key: name to store the data under
- * @data: arbitrary data
- * @destroy_func: (allow-none): function to free @data, or %NULL
- *
- * This function is equivalent to g_object_set_data(),
- * the #GObject variant should be used instead.
- * 
- **/
-void          
-gdk_drawable_set_data (GdkDrawable   *drawable,
-		       const gchar   *key,
-		       gpointer	      data,
-		       GDestroyNotify destroy_func)
-{
-  g_return_if_fail (GDK_IS_DRAWABLE (drawable));
-  
-  g_object_set_qdata_full (G_OBJECT (drawable),
-                           g_quark_from_string (key),
-                           data,
-                           destroy_func);
-}
-
-/**
- * gdk_drawable_get_data:
- * @drawable: a #GdkDrawable
- * @key: name the data was stored under
- * 
- * Equivalent to g_object_get_data(); the #GObject variant should be
- * used instead.
- * 
- * Return value: the data stored at @key
- **/
-gpointer
-gdk_drawable_get_data (GdkDrawable   *drawable,
-		       const gchar   *key)
-{
-  g_return_val_if_fail (GDK_IS_DRAWABLE (drawable), NULL);
-  
-  return g_object_get_qdata (G_OBJECT (drawable),
-                             g_quark_try_string (key));
-}
-
 /**
  * gdk_drawable_get_size:
  * @drawable: a #GdkDrawable
@@ -151,9 +106,8 @@ gdk_drawable_get_data (GdkDrawable   *drawable,
  * On the X11 platform, if @drawable is a #GdkWindow, the returned
  * size is the size reported in the most-recently-processed configure
  * event, rather than the current size on the X server.
- *
- * Deprecated: 2.24: Use gdk_window_get_width() and gdk_window_get_height()
- */
+ * 
+ **/
 void
 gdk_drawable_get_size (GdkDrawable *drawable,
 		       gint        *width,
@@ -161,7 +115,8 @@ gdk_drawable_get_size (GdkDrawable *drawable,
 {
   g_return_if_fail (GDK_IS_DRAWABLE (drawable));
 
-  GDK_DRAWABLE_GET_CLASS (drawable)->get_size (drawable, width, height);  
+  if (GDK_DRAWABLE_GET_CLASS (drawable)->get_size != NULL)
+    GDK_DRAWABLE_GET_CLASS (drawable)->get_size (drawable, width, height);  
 }
 
 /**
@@ -171,9 +126,7 @@ gdk_drawable_get_size (GdkDrawable *drawable,
  * Gets the #GdkVisual describing the pixel format of @drawable.
  * 
  * Return value: a #GdkVisual
- *
- * Deprecated: 2.24: Use gdk_window_get_visual()
- */
+ **/
 GdkVisual*
 gdk_drawable_get_visual (GdkDrawable *drawable)
 {
@@ -208,11 +161,9 @@ gdk_drawable_get_depth (GdkDrawable *drawable)
  * Return value: the #GdkScreen associated with @drawable
  *
  * Since: 2.2
- *
- * Deprecated: 2.24: Use gdk_window_get_screen() instead
  **/
 GdkScreen*
-gdk_drawable_get_screen (GdkDrawable *drawable)
+gdk_drawable_get_screen(GdkDrawable *drawable)
 {
   g_return_val_if_fail (GDK_IS_DRAWABLE (drawable), NULL);
 
@@ -228,17 +179,15 @@ gdk_drawable_get_screen (GdkDrawable *drawable)
  * Return value: the #GdkDisplay associated with @drawable
  *
  * Since: 2.2
- *
- * Deprecated: 2.24: Use gdk_window_get_display() instead
  **/
 GdkDisplay*
 gdk_drawable_get_display (GdkDrawable *drawable)
 {
   g_return_val_if_fail (GDK_IS_DRAWABLE (drawable), NULL);
-
+  
   return gdk_screen_get_display (gdk_drawable_get_screen (drawable));
 }
-
+	
 /**
  * gdk_drawable_set_colormap:
  * @drawable: a #GdkDrawable
@@ -282,39 +231,6 @@ gdk_drawable_get_colormap (GdkDrawable *drawable)
   return GDK_DRAWABLE_GET_CLASS (drawable)->get_colormap (drawable);
 }
 
-/**
- * gdk_drawable_ref:
- * @drawable: a #GdkDrawable
- * 
- * Deprecated equivalent of calling g_object_ref() on @drawable.
- * (Drawables were not objects in previous versions of GDK.)
- * 
- * Return value: the same @drawable passed in
- *
- * Deprecated: 2.0: Use g_object_ref() instead.
- **/
-GdkDrawable*
-gdk_drawable_ref (GdkDrawable *drawable)
-{
-  return (GdkDrawable *) g_object_ref (drawable);
-}
-
-/**
- * gdk_drawable_unref:
- * @drawable: a #GdkDrawable
- *
- * Deprecated equivalent of calling g_object_unref() on @drawable.
- * 
- * Deprecated: 2.0: Use g_object_unref() instead.
- **/
-void
-gdk_drawable_unref (GdkDrawable *drawable)
-{
-  g_return_if_fail (GDK_IS_DRAWABLE (drawable));
-
-  g_object_unref (drawable);
-}
-
 /* Drawing
  */
 
@@ -327,9 +243,6 @@ gdk_drawable_unref (GdkDrawable *drawable)
  * 
  * Draws a point, using the foreground color and other attributes of 
  * the #GdkGC.
- *
- * Deprecated: 2.22: Use cairo_rectangle() and cairo_fill() or 
- * cairo_move_to() and cairo_stroke() instead.
  **/
 void
 gdk_draw_point (GdkDrawable *drawable,
@@ -359,18 +272,6 @@ gdk_draw_point (GdkDrawable *drawable,
  * 
  * Draws a line, using the foreground color and other attributes of 
  * the #GdkGC.
- *
- * Deprecated: 2.22: Use cairo_line_to() and cairo_stroke() instead.
- * Be aware that the default line width in Cairo is 2 pixels and that your
- * coordinates need to describe the center of the line. To draw a single
- * pixel wide pixel-aligned line, you would use:
- * |[cairo_set_line_width (cr, 1.0);
- * cairo_set_line_cap (cr, CAIRO_LINE_CAP_SQUARE);
- * cairo_move_to (cr, 0.5, 0.5);
- * cairo_line_to (cr, 9.5, 0.5);
- * cairo_stroke (cr);]|
- * See also <ulink url="http://cairographics.org/FAQ/#sharp_lines">the Cairo
- * FAQ</ulink> on this topic.
  **/
 void
 gdk_draw_line (GdkDrawable *drawable,
@@ -412,10 +313,6 @@ gdk_draw_line (GdkDrawable *drawable,
  * <literal>gdk_draw_rectangle (window, gc, FALSE, 0, 0, 20, 20)</literal> 
  * results in an outlined rectangle with corners at (0, 0), (0, 20), (20, 20),
  * and (20, 0), which makes it 21 pixels wide and 21 pixels high.
- *
- * Deprecated: 2.22: Use cairo_rectangle() and cairo_fill() or cairo_stroke()
- * instead. For stroking, the same caveats for converting code apply as for
- * gdk_draw_line().
  **/
 void
 gdk_draw_rectangle (GdkDrawable *drawable,
@@ -463,10 +360,6 @@ gdk_draw_rectangle (GdkDrawable *drawable,
  * Draws an arc or a filled 'pie slice'. The arc is defined by the bounding
  * rectangle of the entire ellipse, and the start and end angles of the part 
  * of the ellipse to be drawn.
- *
- * Deprecated: 2.22: Use cairo_arc() and cairo_fill() or cairo_stroke()
- * instead. Note that arcs just like any drawing operation in Cairo are
- * antialiased unless you call cairo_set_antialias().
  **/
 void
 gdk_draw_arc (GdkDrawable *drawable,
@@ -511,9 +404,6 @@ gdk_draw_arc (GdkDrawable *drawable,
  * @n_points: the number of points.
  * 
  * Draws an outlined or filled polygon.
- *
- * Deprecated: 2.22: Use cairo_line_to() or cairo_append_path() and
- * cairo_fill() or cairo_stroke() instead.
  **/
 void
 gdk_draw_polygon (GdkDrawable    *drawable,
@@ -530,106 +420,6 @@ gdk_draw_polygon (GdkDrawable    *drawable,
                                                    n_points);
 }
 
-/* gdk_draw_string
- *
- * Modified by Li-Da Lho to draw 16 bits and Multibyte strings
- *
- * Interface changed: add "GdkFont *font" to specify font or fontset explicitely
- */
-/**
- * gdk_draw_string:
- * @drawable: a #GdkDrawable (a #GdkWindow or a #GdkPixmap).
- * @font: a #GdkFont.
- * @gc: a #GdkGC.
- * @x: the x coordinate of the left edge of the text.
- * @y: the y coordinate of the baseline of the text.
- * @string:  the string of characters to draw.
- * 
- * Draws a string of characters in the given font or fontset.
- * 
- * Deprecated: 2.4: Use gdk_draw_layout() instead.
- **/
-void
-gdk_draw_string (GdkDrawable *drawable,
-		 GdkFont     *font,
-		 GdkGC       *gc,
-		 gint         x,
-		 gint         y,
-		 const gchar *string)
-{
-  gdk_draw_text (drawable, font, gc, x, y, string, _gdk_font_strlen (font, string));
-}
-
-/* gdk_draw_text
- *
- * Modified by Li-Da Lho to draw 16 bits and Multibyte strings
- *
- * Interface changed: add "GdkFont *font" to specify font or fontset explicitely
- */
-/**
- * gdk_draw_text:
- * @drawable: a #GdkDrawable (a #GdkWindow or a #GdkPixmap).
- * @font: a #GdkFont.
- * @gc: a #GdkGC.
- * @x: the x coordinate of the left edge of the text.
- * @y: the y coordinate of the baseline of the text.
- * @text:  the characters to draw.
- * @text_length: the number of characters of @text to draw.
- * 
- * Draws a number of characters in the given font or fontset.
- *
- * Deprecated: 2.4: Use gdk_draw_layout() instead.
- **/
-void
-gdk_draw_text (GdkDrawable *drawable,
-	       GdkFont     *font,
-	       GdkGC       *gc,
-	       gint         x,
-	       gint         y,
-	       const gchar *text,
-	       gint         text_length)
-{
-  g_return_if_fail (GDK_IS_DRAWABLE (drawable));
-  g_return_if_fail (font != NULL);
-  g_return_if_fail (GDK_IS_GC (gc));
-  g_return_if_fail (text != NULL);
-
-  GDK_DRAWABLE_GET_CLASS (drawable)->draw_text (drawable, font, gc, x, y, text, text_length);
-}
-
-/**
- * gdk_draw_text_wc:
- * @drawable: a #GdkDrawable (a #GdkWindow or a #GdkPixmap).
- * @font: a #GdkFont.
- * @gc: a #GdkGC.
- * @x: the x coordinate of the left edge of the text.
- * @y: the y coordinate of the baseline of the text.
- * @text: the wide characters to draw.
- * @text_length: the number of characters to draw.
- * 
- * Draws a number of wide characters using the given font of fontset.
- * If the font is a 1-byte font, the string is converted into 1-byte 
- * characters (discarding the high bytes) before output.
- * 
- * Deprecated: 2.4: Use gdk_draw_layout() instead.
- **/
-void
-gdk_draw_text_wc (GdkDrawable	 *drawable,
-		  GdkFont	 *font,
-		  GdkGC		 *gc,
-		  gint		  x,
-		  gint		  y,
-		  const GdkWChar *text,
-		  gint		  text_length)
-{
-  g_return_if_fail (GDK_IS_DRAWABLE (drawable));
-  g_return_if_fail (font != NULL);
-  g_return_if_fail (GDK_IS_GC (gc));
-  g_return_if_fail (text != NULL);
-
-  GDK_DRAWABLE_GET_CLASS (drawable)->draw_text_wc (drawable, font, gc, x, y, text, text_length);
-}
-
 /**
  * gdk_draw_drawable:
  * @drawable: a #GdkDrawable
@@ -657,10 +447,6 @@ gdk_draw_text_wc (GdkDrawable	 *drawable,
  * a color drawable. The way to draw a bitmap is to set the bitmap as 
  * the stipple on the #GdkGC, set the fill mode to %GDK_STIPPLED, and 
  * then draw the rectangle.
- *
- * Deprecated: 2.22: Use gdk_cairo_set_source_pixmap(), cairo_rectangle()
- * and cairo_fill() to draw pixmap on top of other drawables. Also keep
- * in mind that the limitations on allowed sources do not apply to Cairo.
  **/
 void
 gdk_draw_drawable (GdkDrawable *drawable,
@@ -741,9 +527,6 @@ gdk_draw_drawable (GdkDrawable *drawable,
  * 
  * Draws a #GdkImage onto a drawable.
  * The depth of the #GdkImage must match the depth of the #GdkDrawable.
- *
- * Deprecated: 2.22: Do not use #GdkImage anymore, instead use Cairo image
- * surfaces.
  **/
 void
 gdk_draw_image (GdkDrawable *drawable,
@@ -800,9 +583,6 @@ gdk_draw_image (GdkDrawable *drawable,
  * variable.
  *
  * Since: 2.2
- *
- * Deprecated: 2.22: Use gdk_cairo_set_source_pixbuf() and cairo_paint() or
- * cairo_rectangle() and cairo_fill() instead.
  **/
 void
 gdk_draw_pixbuf (GdkDrawable     *drawable,
@@ -846,9 +626,6 @@ gdk_draw_pixbuf (GdkDrawable     *drawable,
  * 
  * Draws a number of points, using the foreground color and other 
  * attributes of the #GdkGC.
- *
- * Deprecated: 2.22: Use @n_points calls to cairo_rectangle() and
- * cairo_fill() instead.
  **/
 void
 gdk_draw_points (GdkDrawable    *drawable,
@@ -878,10 +655,6 @@ gdk_draw_points (GdkDrawable    *drawable,
  *   @segs array.
  * 
  * Draws a number of unconnected lines.
- *
- * Deprecated: 2.22: Use cairo_move_to(), cairo_line_to() and cairo_stroke()
- * instead. See the documentation of gdk_draw_line() for notes on line drawing
- * with Cairo.
  **/
 void
 gdk_draw_segments (GdkDrawable      *drawable,
@@ -913,9 +686,6 @@ gdk_draw_segments (GdkDrawable      *drawable,
  * The way in which joins between lines are draw is determined by the
  * #GdkCapStyle value in the #GdkGC. This can be set with
  * gdk_gc_set_line_attributes().
- *
- * Deprecated: 2.22: Use cairo_line_to() and cairo_stroke() instead. See the
- * documentation of gdk_draw_line() for notes on line drawing with Cairo.
  **/
 void
 gdk_draw_lines (GdkDrawable    *drawable,
@@ -987,7 +757,6 @@ real_draw_glyphs (GdkDrawable       *drawable,
  * understand; thus, use gdk_draw_layout() instead of this function,
  * gdk_draw_layout() handles the details.
  * 
- * Deprecated: 2.22: Use pango_cairo_show_glyphs() instead.
  **/
 void
 gdk_draw_glyphs (GdkDrawable      *drawable,
@@ -1026,8 +795,6 @@ gdk_draw_glyphs (GdkDrawable      *drawable,
  * See also gdk_draw_glyphs(), gdk_draw_layout().
  *
  * Since: 2.6
- * 
- * Deprecated: 2.22: Use pango_cairo_show_glyphs() instead.
  **/
 void
 gdk_draw_glyphs_transformed (GdkDrawable       *drawable,
@@ -1059,9 +826,6 @@ gdk_draw_glyphs_transformed (GdkDrawable       *drawable,
  * likely not useful for applications.
  *
  * Since: 2.6
- *
- * Deprecated: 2.22: Use Cairo path contruction functions and cairo_fill()
- * instead.
  **/
 void
 gdk_draw_trapezoids (GdkDrawable        *drawable,
@@ -1112,9 +876,6 @@ gdk_draw_trapezoids (GdkDrawable        *drawable,
  *               of @drawable
  * 
  * Since: 2.4
- *
- * Deprecated: 2.22: Use @drawable as the source and draw to a Cairo image
- * surface if you want to download contents to the client.
  **/
 GdkImage*
 gdk_drawable_copy_to_image (GdkDrawable *drawable,
@@ -1211,9 +972,6 @@ gdk_drawable_copy_to_image (GdkDrawable *drawable,
  * will contain undefined data.
  * 
  * Return value: a #GdkImage containing the contents of @drawable
- *
- * Deprecated: 2.22: Use @drawable as the source and draw to a Cairo image
- * surface if you want to download contents to the client.
  **/
 GdkImage*
 gdk_drawable_get_image (GdkDrawable *drawable,
