@@ -90,6 +90,7 @@ gdk_cursor_type_get_type (void)
             { GDK_WATCH, "GDK_WATCH", "watch" },
             { GDK_XTERM, "GDK_XTERM", "xterm" },
             { GDK_LAST_CURSOR, "GDK_LAST_CURSOR", "last-cursor" },
+            { GDK_BLANK_CURSOR, "GDK_BLANK_CURSOR", "blank-cursor" },
             { GDK_CURSOR_IS_PIXMAP, "GDK_CURSOR_IS_PIXMAP", "cursor-is-pixmap" },
             { 0, NULL, NULL }
         };
@@ -98,6 +99,94 @@ gdk_cursor_type_get_type (void)
     return etype;
 }
 
+/* enumerations from "gdkdevice.h" */
+GType
+gdk_extension_mode_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_EXTENSION_EVENTS_NONE, "GDK_EXTENSION_EVENTS_NONE", "none" },
+            { GDK_EXTENSION_EVENTS_ALL, "GDK_EXTENSION_EVENTS_ALL", "all" },
+            { GDK_EXTENSION_EVENTS_CURSOR, "GDK_EXTENSION_EVENTS_CURSOR", "cursor" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkExtensionMode"), values);
+    }
+    return etype;
+}
+
+GType
+gdk_input_source_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_SOURCE_MOUSE, "GDK_SOURCE_MOUSE", "mouse" },
+            { GDK_SOURCE_PEN, "GDK_SOURCE_PEN", "pen" },
+            { GDK_SOURCE_ERASER, "GDK_SOURCE_ERASER", "eraser" },
+            { GDK_SOURCE_CURSOR, "GDK_SOURCE_CURSOR", "cursor" },
+            { GDK_SOURCE_KEYBOARD, "GDK_SOURCE_KEYBOARD", "keyboard" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkInputSource"), values);
+    }
+    return etype;
+}
+
+GType
+gdk_input_mode_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_MODE_DISABLED, "GDK_MODE_DISABLED", "disabled" },
+            { GDK_MODE_SCREEN, "GDK_MODE_SCREEN", "screen" },
+            { GDK_MODE_WINDOW, "GDK_MODE_WINDOW", "window" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkInputMode"), values);
+    }
+    return etype;
+}
+
+GType
+gdk_axis_use_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_AXIS_IGNORE, "GDK_AXIS_IGNORE", "ignore" },
+            { GDK_AXIS_X, "GDK_AXIS_X", "x" },
+            { GDK_AXIS_Y, "GDK_AXIS_Y", "y" },
+            { GDK_AXIS_PRESSURE, "GDK_AXIS_PRESSURE", "pressure" },
+            { GDK_AXIS_XTILT, "GDK_AXIS_XTILT", "xtilt" },
+            { GDK_AXIS_YTILT, "GDK_AXIS_YTILT", "ytilt" },
+            { GDK_AXIS_WHEEL, "GDK_AXIS_WHEEL", "wheel" },
+            { GDK_AXIS_LAST, "GDK_AXIS_LAST", "last" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkAxisUse"), values);
+    }
+    return etype;
+}
+
+GType
+gdk_device_type_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_DEVICE_TYPE_MASTER, "GDK_DEVICE_TYPE_MASTER", "master" },
+            { GDK_DEVICE_TYPE_SLAVE, "GDK_DEVICE_TYPE_SLAVE", "slave" },
+            { GDK_DEVICE_TYPE_FLOATING, "GDK_DEVICE_TYPE_FLOATING", "floating" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkDeviceType"), values);
+    }
+    return etype;
+}
+
 /* enumerations from "gdkdnd.h" */
 GType
 gdk_drag_action_get_type (void)
@@ -199,6 +288,7 @@ gdk_event_type_get_type (void)
             { GDK_OWNER_CHANGE, "GDK_OWNER_CHANGE", "owner-change" },
             { GDK_GRAB_BROKEN, "GDK_GRAB_BROKEN", "grab-broken" },
             { GDK_DAMAGE, "GDK_DAMAGE", "damage" },
+            { GDK_EVENT_LAST, "GDK_EVENT_LAST", "event-last" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GdkEventType"), values);
@@ -206,41 +296,6 @@ gdk_event_type_get_type (void)
     return etype;
 }
 
-GType
-gdk_event_mask_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { GDK_EXPOSURE_MASK, "GDK_EXPOSURE_MASK", "exposure-mask" },
-            { GDK_POINTER_MOTION_MASK, "GDK_POINTER_MOTION_MASK", "pointer-motion-mask" },
-            { GDK_POINTER_MOTION_HINT_MASK, "GDK_POINTER_MOTION_HINT_MASK", "pointer-motion-hint-mask" },
-            { GDK_BUTTON_MOTION_MASK, "GDK_BUTTON_MOTION_MASK", "button-motion-mask" },
-            { GDK_BUTTON1_MOTION_MASK, "GDK_BUTTON1_MOTION_MASK", "button1-motion-mask" },
-            { GDK_BUTTON2_MOTION_MASK, "GDK_BUTTON2_MOTION_MASK", "button2-motion-mask" },
-            { GDK_BUTTON3_MOTION_MASK, "GDK_BUTTON3_MOTION_MASK", "button3-motion-mask" },
-            { GDK_BUTTON_PRESS_MASK, "GDK_BUTTON_PRESS_MASK", "button-press-mask" },
-            { GDK_BUTTON_RELEASE_MASK, "GDK_BUTTON_RELEASE_MASK", "button-release-mask" },
-            { GDK_KEY_PRESS_MASK, "GDK_KEY_PRESS_MASK", "key-press-mask" },
-            { GDK_KEY_RELEASE_MASK, "GDK_KEY_RELEASE_MASK", "key-release-mask" },
-            { GDK_ENTER_NOTIFY_MASK, "GDK_ENTER_NOTIFY_MASK", "enter-notify-mask" },
-            { GDK_LEAVE_NOTIFY_MASK, "GDK_LEAVE_NOTIFY_MASK", "leave-notify-mask" },
-            { GDK_FOCUS_CHANGE_MASK, "GDK_FOCUS_CHANGE_MASK", "focus-change-mask" },
-            { GDK_STRUCTURE_MASK, "GDK_STRUCTURE_MASK", "structure-mask" },
-            { GDK_PROPERTY_CHANGE_MASK, "GDK_PROPERTY_CHANGE_MASK", "property-change-mask" },
-            { GDK_VISIBILITY_NOTIFY_MASK, "GDK_VISIBILITY_NOTIFY_MASK", "visibility-notify-mask" },
-            { GDK_PROXIMITY_IN_MASK, "GDK_PROXIMITY_IN_MASK", "proximity-in-mask" },
-            { GDK_PROXIMITY_OUT_MASK, "GDK_PROXIMITY_OUT_MASK", "proximity-out-mask" },
-            { GDK_SUBSTRUCTURE_MASK, "GDK_SUBSTRUCTURE_MASK", "substructure-mask" },
-            { GDK_SCROLL_MASK, "GDK_SCROLL_MASK", "scroll-mask" },
-            { GDK_ALL_EVENTS_MASK, "GDK_ALL_EVENTS_MASK", "all-events-mask" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GdkEventMask"), values);
-    }
-    return etype;
-}
-
 GType
 gdk_visibility_state_get_type (void)
 {
@@ -302,6 +357,9 @@ gdk_crossing_mode_get_type (void)
             { GDK_CROSSING_NORMAL, "GDK_CROSSING_NORMAL", "normal" },
             { GDK_CROSSING_GRAB, "GDK_CROSSING_GRAB", "grab" },
             { GDK_CROSSING_UNGRAB, "GDK_CROSSING_UNGRAB", "ungrab" },
+            { GDK_CROSSING_GTK_GRAB, "GDK_CROSSING_GTK_GRAB", "gtk-grab" },
+            { GDK_CROSSING_GTK_UNGRAB, "GDK_CROSSING_GTK_UNGRAB", "gtk-ungrab" },
+            { GDK_CROSSING_STATE_CHANGED, "GDK_CROSSING_STATE_CHANGED", "state-changed" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GdkCrossingMode"), values);
@@ -551,77 +609,6 @@ gdk_image_type_get_type (void)
     return etype;
 }
 
-/* enumerations from "gdkinput.h" */
-GType
-gdk_extension_mode_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_EXTENSION_EVENTS_NONE, "GDK_EXTENSION_EVENTS_NONE", "none" },
-            { GDK_EXTENSION_EVENTS_ALL, "GDK_EXTENSION_EVENTS_ALL", "all" },
-            { GDK_EXTENSION_EVENTS_CURSOR, "GDK_EXTENSION_EVENTS_CURSOR", "cursor" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkExtensionMode"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_input_source_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_SOURCE_MOUSE, "GDK_SOURCE_MOUSE", "mouse" },
-            { GDK_SOURCE_PEN, "GDK_SOURCE_PEN", "pen" },
-            { GDK_SOURCE_ERASER, "GDK_SOURCE_ERASER", "eraser" },
-            { GDK_SOURCE_CURSOR, "GDK_SOURCE_CURSOR", "cursor" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkInputSource"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_input_mode_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_MODE_DISABLED, "GDK_MODE_DISABLED", "disabled" },
-            { GDK_MODE_SCREEN, "GDK_MODE_SCREEN", "screen" },
-            { GDK_MODE_WINDOW, "GDK_MODE_WINDOW", "window" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkInputMode"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_axis_use_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_AXIS_IGNORE, "GDK_AXIS_IGNORE", "ignore" },
-            { GDK_AXIS_X, "GDK_AXIS_X", "x" },
-            { GDK_AXIS_Y, "GDK_AXIS_Y", "y" },
-            { GDK_AXIS_PRESSURE, "GDK_AXIS_PRESSURE", "pressure" },
-            { GDK_AXIS_XTILT, "GDK_AXIS_XTILT", "xtilt" },
-            { GDK_AXIS_YTILT, "GDK_AXIS_YTILT", "ytilt" },
-            { GDK_AXIS_WHEEL, "GDK_AXIS_WHEEL", "wheel" },
-            { GDK_AXIS_LAST, "GDK_AXIS_LAST", "last" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkAxisUse"), values);
-    }
-    return etype;
-}
-
 /* enumerations from "gdkproperty.h" */
 GType
 gdk_prop_mode_get_type (void)
@@ -735,22 +722,6 @@ gdk_modifier_type_get_type (void)
     return etype;
 }
 
-GType
-gdk_input_condition_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { GDK_INPUT_READ, "GDK_INPUT_READ", "read" },
-            { GDK_INPUT_WRITE, "GDK_INPUT_WRITE", "write" },
-            { GDK_INPUT_EXCEPTION, "GDK_INPUT_EXCEPTION", "exception" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GdkInputCondition"), values);
-    }
-    return etype;
-}
-
 GType
 gdk_status_get_type (void)
 {
@@ -787,6 +758,57 @@ gdk_grab_status_get_type (void)
     return etype;
 }
 
+GType
+gdk_grab_ownership_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GDK_OWNERSHIP_NONE, "GDK_OWNERSHIP_NONE", "none" },
+            { GDK_OWNERSHIP_WINDOW, "GDK_OWNERSHIP_WINDOW", "window" },
+            { GDK_OWNERSHIP_APPLICATION, "GDK_OWNERSHIP_APPLICATION", "application" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GdkGrabOwnership"), values);
+    }
+    return etype;
+}
+
+GType
+gdk_event_mask_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GFlagsValue values[] = {
+            { GDK_EXPOSURE_MASK, "GDK_EXPOSURE_MASK", "exposure-mask" },
+            { GDK_POINTER_MOTION_MASK, "GDK_POINTER_MOTION_MASK", "pointer-motion-mask" },
+            { GDK_POINTER_MOTION_HINT_MASK, "GDK_POINTER_MOTION_HINT_MASK", "pointer-motion-hint-mask" },
+            { GDK_BUTTON_MOTION_MASK, "GDK_BUTTON_MOTION_MASK", "button-motion-mask" },
+            { GDK_BUTTON1_MOTION_MASK, "GDK_BUTTON1_MOTION_MASK", "button1-motion-mask" },
+            { GDK_BUTTON2_MOTION_MASK, "GDK_BUTTON2_MOTION_MASK", "button2-motion-mask" },
+            { GDK_BUTTON3_MOTION_MASK, "GDK_BUTTON3_MOTION_MASK", "button3-motion-mask" },
+            { GDK_BUTTON_PRESS_MASK, "GDK_BUTTON_PRESS_MASK", "button-press-mask" },
+            { GDK_BUTTON_RELEASE_MASK, "GDK_BUTTON_RELEASE_MASK", "button-release-mask" },
+            { GDK_KEY_PRESS_MASK, "GDK_KEY_PRESS_MASK", "key-press-mask" },
+            { GDK_KEY_RELEASE_MASK, "GDK_KEY_RELEASE_MASK", "key-release-mask" },
+            { GDK_ENTER_NOTIFY_MASK, "GDK_ENTER_NOTIFY_MASK", "enter-notify-mask" },
+            { GDK_LEAVE_NOTIFY_MASK, "GDK_LEAVE_NOTIFY_MASK", "leave-notify-mask" },
+            { GDK_FOCUS_CHANGE_MASK, "GDK_FOCUS_CHANGE_MASK", "focus-change-mask" },
+            { GDK_STRUCTURE_MASK, "GDK_STRUCTURE_MASK", "structure-mask" },
+            { GDK_PROPERTY_CHANGE_MASK, "GDK_PROPERTY_CHANGE_MASK", "property-change-mask" },
+            { GDK_VISIBILITY_NOTIFY_MASK, "GDK_VISIBILITY_NOTIFY_MASK", "visibility-notify-mask" },
+            { GDK_PROXIMITY_IN_MASK, "GDK_PROXIMITY_IN_MASK", "proximity-in-mask" },
+            { GDK_PROXIMITY_OUT_MASK, "GDK_PROXIMITY_OUT_MASK", "proximity-out-mask" },
+            { GDK_SUBSTRUCTURE_MASK, "GDK_SUBSTRUCTURE_MASK", "substructure-mask" },
+            { GDK_SCROLL_MASK, "GDK_SCROLL_MASK", "scroll-mask" },
+            { GDK_ALL_EVENTS_MASK, "GDK_ALL_EVENTS_MASK", "all-events-mask" },
+            { 0, NULL, NULL }
+        };
+        etype = g_flags_register_static (g_intern_static_string ("GdkEventMask"), values);
+    }
+    return etype;
+}
+
 /* enumerations from "gdkvisual.h" */
 GType
 gdk_visual_type_get_type (void)
@@ -835,6 +857,7 @@ gdk_window_type_get_type (void)
             { GDK_WINDOW_DIALOG, "GDK_WINDOW_DIALOG", "dialog" },
             { GDK_WINDOW_TEMP, "GDK_WINDOW_TEMP", "temp" },
             { GDK_WINDOW_FOREIGN, "GDK_WINDOW_FOREIGN", "foreign" },
+            { GDK_WINDOW_OFFSCREEN, "GDK_WINDOW_OFFSCREEN", "offscreen" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static (g_intern_static_string ("GdkWindowType"), values);
