@@ -27,7 +27,6 @@
 #include <gdk/gdkprivate.h>
 #include <gdk/quartz/gdkpixmap-quartz.h>
 #include <gdk/quartz/gdkwindow-quartz.h>
-#include <gdk/quartz/gdkquartz.h>
 
 #include <gdk/gdk.h>
 
@@ -72,7 +71,6 @@ struct _GdkGCQuartz
   CGFloat           dash_phase;
 
   CGPatternRef      ts_pattern;
-  void             *ts_pattern_info;
 
   guint             is_window : 1;
 };
@@ -125,14 +123,18 @@ GType  _gdk_gc_quartz_get_type          (void);
 GdkGC *_gdk_quartz_gc_new               (GdkDrawable                *drawable,
 					 GdkGCValues                *values,
 					 GdkGCValuesMask             values_mask);
-gboolean _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
-					   GdkDrawable                *drawable,
-					   CGContextRef                context,
-					   GdkQuartzContextValuesMask  mask);
+void   _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
+					 GdkDrawable                *drawable,
+					 CGContextRef                context,
+					 GdkQuartzContextValuesMask  mask);
 
 /* Colormap */
-CGColorRef _gdk_quartz_colormap_get_cgcolor_from_pixel (GdkDrawable *drawable,
-                                                        guint32      pixel);
+void _gdk_quartz_colormap_get_rgba_from_pixel (GdkColormap *colormap,
+					       guint32      pixel,
+					       CGFloat     *red,
+					       CGFloat     *green,
+					       CGFloat     *blue,
+					       CGFloat     *alpha);
 
 /* Window */
 gboolean    _gdk_quartz_window_is_ancestor          (GdkWindow *ancestor,
@@ -150,7 +152,8 @@ void       _gdk_quartz_window_nspoint_to_gdk_xy     (NSPoint    point,
                                                      gint      *y);
 GdkWindow *_gdk_quartz_window_find_child            (GdkWindow *window,
 						     gint       x,
-						     gint       y);
+						     gint       y,
+                                                     gboolean   get_toplevel);
 void       _gdk_quartz_window_attach_to_parent      (GdkWindow *window);
 void       _gdk_quartz_window_detach_from_parent    (GdkWindow *window);
 void       _gdk_quartz_window_did_become_main       (GdkWindow *window);
@@ -173,9 +176,6 @@ void         _gdk_quartz_events_update_focus_window    (GdkWindow *new_window,
 void         _gdk_quartz_events_send_map_event         (GdkWindow *window);
 GdkEventMask _gdk_quartz_events_get_current_event_mask (void);
 
-GdkModifierType _gdk_quartz_events_get_current_keyboard_modifiers (void);
-GdkModifierType _gdk_quartz_events_get_current_mouse_modifiers    (void);
-
 void         _gdk_quartz_events_send_enter_notify_event (GdkWindow *window);
 
 /* Event loop */
@@ -213,7 +213,4 @@ void        _gdk_quartz_window_queue_translation (GdkWindow *window,
 gboolean    _gdk_quartz_window_queue_antiexpose  (GdkWindow *window,
                                                   GdkRegion *area);
 
-/* Pixmap */
-CGImageRef _gdk_pixmap_get_cgimage (GdkPixmap *pixmap);
-
 #endif /* __GDK_PRIVATE_QUARTZ_H__ */
