@@ -25,7 +25,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -51,7 +51,7 @@ gdk_colormap_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (GdkColormapClass),
         (GBaseInitFunc) NULL,
@@ -570,9 +570,6 @@ gdk_colormap_new (GdkVisual *visual,
       if (private_cmap)
 	{
 	  sync_colors (colormap);
-#if 0 /* XXX is this needed or not? Seems redundant */
-	  gdk_colormap_change (colormap, colormap->size);
-#endif
 	}
       break;
 
@@ -599,6 +596,8 @@ gdk_screen_get_system_colormap (GdkScreen *screen)
   static GdkColormap *colormap = NULL;
   GdkColormapPrivateWin32 *private;
 
+  g_return_val_if_fail (screen == _gdk_screen, NULL);
+
   if (!colormap)
     {
       colormap = g_object_new (gdk_colormap_get_type (), NULL);
@@ -638,82 +637,7 @@ gdk_screen_get_system_colormap (GdkScreen *screen)
   return colormap;
 }
 
-gint
-gdk_colormap_get_system_size (void)
-{
-  return gdk_colormap_get_system ()->size;
-}
-
-void
-gdk_colormap_change (GdkColormap *colormap,
-		     gint         ncolors)
-{
-  GdkColormapPrivateWin32 *cmapp;
-  PALETTEENTRY *pe;
-  int i;
-
-  g_return_if_fail (colormap != NULL);
-
-  cmapp = GDK_WIN32_COLORMAP_DATA (colormap);
-
-  GDK_NOTE (COLORMAP, g_print ("gdk_colormap_change: hpal=%p ncolors=%d\n",
-			       cmapp->hpal, ncolors));
-
-  switch (colormap->visual->type)
-    {
-    case GDK_VISUAL_GRAYSCALE:
-    case GDK_VISUAL_PSEUDO_COLOR:
-      pe = g_new (PALETTEENTRY, ncolors);
-
-      for (i = 0; i < ncolors; i++)
-	{
-	  pe[i].peRed = (colormap->colors[i].red >> 8);
-	  pe[i].peGreen = (colormap->colors[i].green >> 8);
-	  pe[i].peBlue = (colormap->colors[i].blue >> 8);
-	  pe[i].peFlags = 0;
-	}
-
-      GDI_CALL (SetPaletteEntries, (cmapp->hpal, 0, ncolors, pe));
-      g_free (pe);
-      break;
-
-    default:
-      break;
-    }
-}
-
-gboolean
-gdk_colors_alloc (GdkColormap   *colormap,
-		  gboolean       contiguous,
-		  gulong        *planes,
-		  gint           nplanes,
-		  gulong        *pixels,
-		  gint           npixels)
-{
-  GdkColormapPrivateWin32 *private;
-  gint return_val;
-  gint i;
-
-  g_return_val_if_fail (GDK_IS_COLORMAP (colormap), 0);
-
-  private = GDK_WIN32_COLORMAP_DATA (colormap);
-
-  return_val = alloc_color_cells (colormap, contiguous,
-				  planes, nplanes, pixels, npixels);
-
-  if (return_val)
-    {
-      for (i = 0; i < npixels; i++)
-	{
-	  private->info[pixels[i]].ref_count++;
-	  private->info[pixels[i]].flags |= GDK_COLOR_WRITEABLE;
-	}
-    }
-
-  return return_val != 0;
-}
-
-void
+static void
 gdk_colors_free (GdkColormap *colormap,
 		 gulong      *in_pixels,
 		 gint         in_npixels,
@@ -763,9 +687,9 @@ gdk_colors_free (GdkColormap *colormap,
 }
 
 void
-gdk_colormap_free_colors (GdkColormap *colormap,
-			  GdkColor    *colors,
-			  gint         ncolors)
+gdk_colormap_free_colors (GdkColormap    *colormap,
+			  const GdkColor *colors,
+			  gint            ncolors)
 {
   gulong *pixels;
   gint i;
@@ -1143,6 +1067,7 @@ gdk_colormap_alloc_colors (GdkColormap *colormap,
 
   g_return_val_if_fail (GDK_IS_COLORMAP (colormap), FALSE);
   g_return_val_if_fail (colors != NULL, FALSE);
+  g_return_val_if_fail (success != NULL, ncolors);
 
   private = GDK_WIN32_COLORMAP_DATA (colormap);
 
@@ -1233,33 +1158,6 @@ gdk_colormap_query_color (GdkColormap *colormap,
     }
 }
 
-gboolean
-gdk_color_change (GdkColormap *colormap,
-		  GdkColor    *color)
-{
-  GdkColormapPrivateWin32 *private;
-  PALETTEENTRY pe;
-
-  g_return_val_if_fail (GDK_IS_COLORMAP (colormap), FALSE);
-  g_return_val_if_fail (color != NULL, FALSE);
-
-  private = GDK_WIN32_COLORMAP_DATA (colormap);
-
-  if (color->pixel < 0 || color->pixel >= colormap->size)
-    return FALSE;
-
-  if (private->use[color->pixel] == GDK_WIN32_PE_STATIC)
-    return FALSE;
-
-  pe.peRed = color->red >> 8;
-  pe.peGreen = color->green >> 8;
-  pe.peBlue = color->blue >> 8;
-
-  GDI_CALL (SetPaletteEntries, (private->hpal, color->pixel, 1, &pe));
-
-  return TRUE;
-}
-
 static gint
 gdk_colormap_match_color (GdkColormap *cmap,
 			  GdkColor    *color,
@@ -1301,8 +1199,8 @@ gdk_colormap_match_color (GdkColormap *cmap,
 GdkScreen*
 gdk_colormap_get_screen (GdkColormap *cmap)
 {
-  g_return_val_if_fail (cmap != NULL, NULL);
+  g_return_val_if_fail (GDK_IS_COLORMAP (cmap), NULL);
 
-  return gdk_screen_get_default ();
+  return _gdk_screen;
 }
 
