@@ -24,8 +24,28 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+/**
+ * SECTION:gtkalignment
+ * @Short_description: A widget which controls the alignment and size of its child
+ * @Title: GtkAlignment
+ *
+ * The #GtkAlignment widget controls the alignment and size of its child widget.
+ * It has four settings: xscale, yscale, xalign, and yalign.
+ *
+ * The scale settings are used to specify how much the child widget should
+ * expand to fill the space allocated to the #GtkAlignment.
+ * The values can range from 0 (meaning the child doesn't expand at all) to
+ * 1 (meaning the child expands to fill all of the available space).
+ *
+ * The align settings are used to place the child widget within the available
+ * area. The values range from 0 (top or left) to 1 (bottom or right).
+ * Of course, if the scale settings are both set to 1, the alignment settings
+ * have no effect.
+ */
+
 #include "config.h"
 #include "gtkalignment.h"
+#include "gtksizerequest.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
 #include "gtkalias.h"
@@ -54,8 +74,6 @@ struct _GtkAlignmentPrivate
   guint padding_right;
 };
 
-static void gtk_alignment_size_request  (GtkWidget         *widget,
-					 GtkRequisition    *requisition);
 static void gtk_alignment_size_allocate (GtkWidget         *widget,
 					 GtkAllocation     *allocation);
 static void gtk_alignment_set_property (GObject         *object,
@@ -67,7 +85,17 @@ static void gtk_alignment_get_property (GObject         *object,
                                         GValue          *value,
                                         GParamSpec      *pspec);
 
-G_DEFINE_TYPE (GtkAlignment, gtk_alignment, GTK_TYPE_BIN)
+static void gtk_alignment_size_request_init  (GtkSizeRequestIface *iface);
+static void gtk_alignment_get_width          (GtkSizeRequest      *widget,
+					      gint                *minimum_size,
+					      gint                *natural_size);
+static void gtk_alignment_get_height         (GtkSizeRequest      *widget,
+					      gint                *minimum_size,
+					      gint                *natural_size);
+
+G_DEFINE_TYPE_WITH_CODE (GtkAlignment, gtk_alignment, GTK_TYPE_BIN,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SIZE_REQUEST,
+						gtk_alignment_size_request_init))
 
 static void
 gtk_alignment_class_init (GtkAlignmentClass *class)
@@ -81,7 +109,6 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
   gobject_class->set_property = gtk_alignment_set_property;
   gobject_class->get_property = gtk_alignment_get_property;
 
-  widget_class->size_request = gtk_alignment_size_request;
   widget_class->size_allocate = gtk_alignment_size_allocate;
 
   g_object_class_install_property (gobject_class,
@@ -199,7 +226,7 @@ gtk_alignment_init (GtkAlignment *alignment)
 {
   GtkAlignmentPrivate *priv;
   
-  GTK_WIDGET_SET_FLAGS (alignment, GTK_NO_WINDOW);
+  gtk_widget_set_has_window (GTK_WIDGET (alignment), FALSE);
   gtk_widget_set_redraw_on_allocate (GTK_WIDGET (alignment), FALSE);
 
   alignment->xalign = 0.5;
@@ -215,6 +242,24 @@ gtk_alignment_init (GtkAlignment *alignment)
   priv->padding_right = 0;
 }
 
+/**
+ * gtk_alignment_new:
+ * @xalign: the horizontal alignment of the child widget, from 0 (left) to 1
+ *  (right).
+ * @yalign: the vertical alignment of the child widget, from 0 (top) to 1
+ *  (bottom).
+ * @xscale: the amount that the child widget expands horizontally to fill up
+ *  unused space, from 0 to 1.
+ *  A value of 0 indicates that the child widget should never expand.
+ *  A value of 1 indicates that the child widget will expand to fill all of the
+ *  space allocated for the #GtkAlignment.
+ * @yscale: the amount that the child widget expands vertically to fill up
+ *  unused space, from 0 to 1. The values are similar to @xscale.
+ *
+ * Creates a new #GtkAlignment.
+ *
+ * Returns: the new #GtkAlignment.
+ */
 GtkWidget*
 gtk_alignment_new (gfloat xalign,
 		   gfloat yalign,
@@ -359,6 +404,23 @@ gtk_alignment_get_property (GObject         *object,
     }
 }
 
+/**
+ * gtk_alignment_set:
+ * @alignment: a #GtkAlignment.
+ * @xalign: the horizontal alignment of the child widget, from 0 (left) to 1
+ *  (right).
+ * @yalign: the vertical alignment of the child widget, from 0 (top) to 1
+ *  (bottom).
+ * @xscale: the amount that the child widget expands horizontally to fill up
+ *  unused space, from 0 to 1.
+ *  A value of 0 indicates that the child widget should never expand.
+ *  A value of 1 indicates that the child widget will expand to fill all of the
+ *  space allocated for the #GtkAlignment.
+ * @yscale: the amount that the child widget expands vertically to fill up
+ *  unused space, from 0 to 1. The values are similar to @xscale.
+ *
+ * Sets the #GtkAlignment values.
+ */
 void
 gtk_alignment_set (GtkAlignment *alignment,
 		   gfloat        xalign,
@@ -408,34 +470,6 @@ gtk_alignment_set (GtkAlignment *alignment,
 }
 
 
-static void
-gtk_alignment_size_request (GtkWidget      *widget,
-			    GtkRequisition *requisition)
-{
-  GtkBin *bin;
-  GtkAlignmentPrivate *priv;
-
-  bin = GTK_BIN (widget);
-  priv = GTK_ALIGNMENT_GET_PRIVATE (widget);
-
-  requisition->width = GTK_CONTAINER (widget)->border_width * 2;
-  requisition->height = GTK_CONTAINER (widget)->border_width * 2;
-
-  if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
-    {
-      GtkRequisition child_requisition;
-      
-      gtk_widget_size_request (bin->child, &child_requisition);
-
-      requisition->width += child_requisition.width;
-      requisition->height += child_requisition.height;
-
-      /* Request extra space for the padding: */
-      requisition->width += (priv->padding_left + priv->padding_right);
-      requisition->height += (priv->padding_top + priv->padding_bottom);
-    }
-}
-
 static void
 gtk_alignment_size_allocate (GtkWidget     *widget,
 			     GtkAllocation *allocation)
@@ -443,7 +477,6 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   GtkAlignment *alignment;
   GtkBin *bin;
   GtkAllocation child_allocation;
-  GtkRequisition child_requisition;
   gint width, height;
   gint border_width;
   gint padding_horizontal, padding_vertical;
@@ -456,9 +489,12 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   alignment = GTK_ALIGNMENT (widget);
   bin = GTK_BIN (widget);
   
-  if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
+  if (bin->child && gtk_widget_get_visible (bin->child))
     {
-      gtk_widget_get_child_requisition (bin->child, &child_requisition);
+      GtkSizeRequest *child = GTK_SIZE_REQUEST (bin->child);
+      gint child_nat_width;
+      gint child_nat_height;
+      gint child_width, child_height;
 
       border_width = GTK_CONTAINER (alignment)->border_width;
 
@@ -468,16 +504,37 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
 
       width  = MAX (1, allocation->width - padding_horizontal - 2 * border_width);
       height = MAX (1, allocation->height - padding_vertical - 2 * border_width);
-    
-      if (width > child_requisition.width)
-	child_allocation.width = (child_requisition.width *
+
+      if (gtk_size_request_get_request_mode (child) == GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH)
+	{
+	  gtk_size_request_get_width (child, NULL, &child_nat_width);
+
+	  child_width = MIN (width, child_nat_width);
+
+	  gtk_size_request_get_height_for_width (child, child_width, NULL, &child_nat_height);
+
+	  child_height = MIN (height, child_nat_height);
+	}
+      else
+	{
+	  gtk_size_request_get_height (child, NULL, &child_nat_height);
+
+	  child_height = MIN (height, child_nat_height);
+
+	  gtk_size_request_get_width_for_height (child, child_height, NULL, &child_nat_width);
+
+	  child_width = MIN (width, child_nat_width);
+	}
+
+      if (width > child_width)
+	child_allocation.width = (child_width *
 				  (1.0 - alignment->xscale) +
 				  width * alignment->xscale);
       else
 	child_allocation.width = width;
-      
-      if (height > child_requisition.height)
-	child_allocation.height = (child_requisition.height *
+
+      if (height > child_height)
+	child_allocation.height = (child_height *
 				   (1.0 - alignment->yscale) +
 				   height * alignment->yscale);
       else
@@ -494,6 +551,75 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
     }
 }
 
+
+static void
+gtk_alignment_size_request_init (GtkSizeRequestIface *iface)
+{
+  iface->get_width  = gtk_alignment_get_width;
+  iface->get_height = gtk_alignment_get_height;
+}
+
+static void
+gtk_alignment_get_size (GtkSizeRequest *widget,
+			GtkOrientation  orientation,
+			gint           *minimum_size,
+			gint           *natural_size)
+{
+  GtkWidget *child;
+  GtkAlignmentPrivate *priv;
+  gint minimum, natural;
+
+  priv = GTK_ALIGNMENT_GET_PRIVATE (widget);
+
+  natural = minimum = GTK_CONTAINER (widget)->border_width * 2;
+
+  if ((child = gtk_bin_get_child (GTK_BIN (widget))) && gtk_widget_get_visible (child))
+    {
+      gint child_min, child_nat;
+
+      /* Request extra space for the padding: */
+      if (orientation == GTK_ORIENTATION_HORIZONTAL)
+	{
+	  minimum += (priv->padding_left + priv->padding_right);
+	  gtk_size_request_get_width (GTK_SIZE_REQUEST (child), 
+				      &child_min, &child_nat);
+	}
+      else
+	{
+	  minimum += (priv->padding_top + priv->padding_bottom);
+	  gtk_size_request_get_height (GTK_SIZE_REQUEST (child), 
+				       &child_min, &child_nat);
+	}
+
+      natural = minimum;
+
+      minimum += child_min;
+      natural += child_nat;
+    }
+
+  if (minimum_size)
+    *minimum_size = minimum;
+
+  if (natural_size)
+    *natural_size = natural;
+}
+
+static void
+gtk_alignment_get_width (GtkSizeRequest *widget,
+			 gint           *minimum_size,
+			 gint           *natural_size)
+{
+  gtk_alignment_get_size (widget, GTK_ORIENTATION_HORIZONTAL, minimum_size, natural_size);
+}
+
+static void
+gtk_alignment_get_height (GtkSizeRequest *widget,
+			  gint           *minimum_size,
+			  gint           *natural_size)
+{
+  gtk_alignment_get_size (widget, GTK_ORIENTATION_VERTICAL, minimum_size, natural_size);
+}
+
 /**
  * gtk_alignment_set_padding:
  * @alignment: a #GtkAlignment
