@@ -21,11 +21,41 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
+ */
+
+/**
+ * SECTION:gtkbbox
+ * @Short_description: Base class for GtkHButtonBox and GtkVButtonBox
+ * @Title: GtkButtonBox
+ * @See_also: #GtkVButtonBox, #GtkHButtonBox
+ *
+ * The primary purpose of this class is to keep track of the various properties
+ * of #GtkHButtonBox and #GtkVButtonBox widgets.
+ *
+ * gtk_button_box_get_child_size() retrieves the minimum width and height
+ * for widgets in a given button box.
+ *
+ * The internal padding of buttons can be retrieved and changed per button box
+ * using gtk_button_box_get_child_ipadding() and
+ * gtk_button_box_set_child_ipadding() respectively.
+ *
+ * gtk_button_box_get_spacing() and gtk_button_box_set_spacing() retrieve and
+ * change default number of pixels between buttons, respectively.
+ *
+ * gtk_button_box_get_layout() and gtk_button_box_set_layout() retrieve and
+ * alter the method used to spread the buttons in a button box across the
+ * container, respectively.
+ *
+ * The main purpose of GtkButtonBox is to make sure the children have all the
+ * same size. Therefore it ignores the homogeneous property which it inherited
+ * from GtkBox, and always behaves as if homogeneous was %TRUE.
  */
 
 #include "config.h"
 #include "gtkbbox.h"
+#include "gtkhbbox.h"
+#include "gtkvbbox.h"
 #include "gtkorientable.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
@@ -49,10 +79,10 @@ static void gtk_button_box_get_property       (GObject           *object,
 					       guint              prop_id,
 					       GValue            *value,
 					       GParamSpec        *pspec);
-static void gtk_button_box_size_request  (GtkWidget      *widget,
-                                          GtkRequisition *requisition);
-static void gtk_button_box_size_allocate (GtkWidget      *widget,
-                                          GtkAllocation  *allocation);
+static void gtk_button_box_size_request       (GtkWidget         *widget,
+                                               GtkRequisition    *requisition);
+static void gtk_button_box_size_allocate      (GtkWidget         *widget,
+                                               GtkAllocation     *allocation);
 static void gtk_button_box_set_child_property (GtkContainer      *container,
 					       GtkWidget         *child,
 					       guint              property_id,
@@ -69,7 +99,7 @@ static void gtk_button_box_get_child_property (GtkContainer      *container,
 #define DEFAULT_CHILD_IPAD_X 4
 #define DEFAULT_CHILD_IPAD_Y 0
 
-G_DEFINE_ABSTRACT_TYPE (GtkButtonBox, gtk_button_box, GTK_TYPE_BOX)
+G_DEFINE_TYPE (GtkButtonBox, gtk_button_box, GTK_TYPE_BOX)
 
 static void
 gtk_button_box_class_init (GtkButtonBoxClass *class)
@@ -90,7 +120,7 @@ gtk_button_box_class_init (GtkButtonBoxClass *class)
 
   container_class->set_child_property = gtk_button_box_set_child_property;
   container_class->get_child_property = gtk_button_box_get_child_property;
-  
+
   /* FIXME we need to override the "spacing" property on GtkBox once
    * libgobject allows that.
    */
@@ -164,7 +194,7 @@ gtk_button_box_set_property (GObject         *object,
 			     const GValue    *value,
 			     GParamSpec      *pspec)
 {
-  switch (prop_id) 
+  switch (prop_id)
     {
     case PROP_LAYOUT_STYLE:
       gtk_button_box_set_layout (GTK_BUTTON_BOX (object),
@@ -232,28 +262,13 @@ gtk_button_box_get_child_property (GtkContainer *container,
     }
 }
 
-/* set per widget values for spacing, child size and child internal padding */
-
-void 
-gtk_button_box_set_child_size (GtkButtonBox *widget, 
-                               gint width, gint height)
-{
-  g_return_if_fail (GTK_IS_BUTTON_BOX (widget));
-
-  widget->child_min_width = width;
-  widget->child_min_height = height;
-}
-
-void 
-gtk_button_box_set_child_ipadding (GtkButtonBox *widget,
-                                   gint ipad_x, gint ipad_y)
-{
-  g_return_if_fail (GTK_IS_BUTTON_BOX (widget));
-
-  widget->child_ipad_x = ipad_x;
-  widget->child_ipad_y = ipad_y;
-}
-
+/**
+ * gtk_button_box_set_layout:
+ * @widget: a #GtkButtonBox
+ * @layout_style: the new layout style
+ *
+ * Changes the way buttons are arranged in their container.
+ */
 void
 gtk_button_box_set_layout (GtkButtonBox      *widget, 
                            GtkButtonBoxStyle  layout_style)
@@ -270,33 +285,14 @@ gtk_button_box_set_layout (GtkButtonBox      *widget,
     }
 }
 
-
-/* get per widget values for spacing, child size and child internal padding */
-
-void 
-gtk_button_box_get_child_size (GtkButtonBox *widget,
-                               gint *width, gint *height)
-{
-  g_return_if_fail (GTK_IS_BUTTON_BOX (widget));
-  g_return_if_fail (width != NULL);
-  g_return_if_fail (height != NULL);
-
-  *width  = widget->child_min_width;
-  *height = widget->child_min_height;
-}
-
-void
-gtk_button_box_get_child_ipadding (GtkButtonBox *widget,
-                                   gint* ipad_x, gint *ipad_y)
-{
-  g_return_if_fail (GTK_IS_BUTTON_BOX (widget));
-  g_return_if_fail (ipad_x != NULL);
-  g_return_if_fail (ipad_y != NULL);
-
-  *ipad_x = widget->child_ipad_x;
-  *ipad_y = widget->child_ipad_y;
-}
-
+/**
+ * gtk_button_box_get_layout:
+ * @widget: a #GtkButtonBox
+ *
+ * Retrieves the method being used to arrange the buttons in a button box.
+ *
+ * Returns: the method used to layout buttons in @widget.
+ */
 GtkButtonBoxStyle 
 gtk_button_box_get_layout (GtkButtonBox *widget)
 {
@@ -388,7 +384,8 @@ gtk_button_box_set_child_secondary (GtkButtonBox *widget,
 
   gtk_widget_child_notify (child, "secondary");
 
-  if (GTK_WIDGET_VISIBLE (widget) && GTK_WIDGET_VISIBLE (child))
+  if (gtk_widget_get_visible (GTK_WIDGET (widget))
+      && gtk_widget_get_visible (child))
     gtk_widget_queue_resize (child);
 }
 
@@ -455,11 +452,11 @@ _gtk_button_box_child_requisition (GtkWidget *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  nchildren += 1;
 	  gtk_widget_size_request (child->widget, &child_requisition);
-	  
+
 	  if (child_requisition.width + ipad_w > needed_width)
 	    needed_width = child_requisition.width + ipad_w;
 	  if (child_requisition.height + ipad_h > needed_height)
@@ -491,9 +488,9 @@ gtk_button_box_kludge_get_layout_default (GtkButtonBox *widget)
   orientation = gtk_orientable_get_orientation (GTK_ORIENTABLE (widget));
 
   if (orientation == GTK_ORIENTATION_HORIZONTAL)
-    return gtk_hbutton_box_get_layout_default ();
+    return _gtk_hbutton_box_get_layout_default ();
   else
-    return gtk_vbutton_box_get_layout_default ();
+    return _gtk_vbutton_box_get_layout_default ();
 }
 
 static void
@@ -558,14 +555,10 @@ gtk_button_box_size_request (GtkWidget      *widget,
             break;
         }
 
-        if (orientation == GTK_ORIENTATION_HORIZONTAL)
-        {
-          requisition->height = child_height;
-        }
-        else
-        {
-          requisition->width = child_width;
-        }
+      if (orientation == GTK_ORIENTATION_HORIZONTAL)
+        requisition->height = child_height;
+      else
+        requisition->width = child_width;
     }
 
   requisition->width += GTK_CONTAINER (box)->border_width * 2;
@@ -589,8 +582,8 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
   gint y = 0;
   gint secondary_x = 0;
   gint secondary_y = 0;
-  gint width;
-  gint height;
+  gint width = 0;
+  gint height = 0;
   gint childspace;
   gint childspacing = 0;
   GtkButtonBoxStyle layout;
@@ -645,20 +638,20 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
         if (orientation == GTK_ORIENTATION_HORIZONTAL)
           {
             if (nvis_children >= 2)
-            {
-              childspacing = (width - (nvis_children * child_width))
+              {
+                childspacing = (width - (nvis_children * child_width))
                       / (nvis_children - 1);
-              x = allocation->x + GTK_CONTAINER (box)->border_width;
-              secondary_x = x + ((nvis_children - n_secondaries)
-                              * (child_width + childspacing));
-            }
-          else
-            {
-              /* one or zero children, just center */
-              childspacing = width;
-              x = secondary_x = allocation->x
+                x = allocation->x + GTK_CONTAINER (box)->border_width;
+                secondary_x = x + ((nvis_children - n_secondaries)
+                                   * (child_width + childspacing));
+              }
+            else
+              {
+                /* one or zero children, just center */
+                childspacing = width;
+                x = secondary_x = allocation->x
                       + (allocation->width - child_width) / 2;
-            }
+              }
           }
         else
           {
@@ -735,8 +728,8 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
             x = allocation->x +
               (allocation->width
                - (child_width * (nvis_children - n_secondaries)
-               + spacing * (nvis_children - n_secondaries - 1)))/2
-              + (n_secondaries * child_width + n_secondaries * spacing)/2;
+               + spacing * (nvis_children - n_secondaries - 1))) / 2
+              + (n_secondaries * child_width + n_secondaries * spacing) / 2;
             secondary_x = allocation->x + GTK_CONTAINER (box)->border_width;
           }
         else
@@ -745,15 +738,15 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
             y = allocation->y +
               (allocation->height
                - (child_height * (nvis_children - n_secondaries)
-                  + spacing * (nvis_children - n_secondaries - 1)))/2
-              + (n_secondaries * child_height + n_secondaries * spacing)/2;
+                  + spacing * (nvis_children - n_secondaries - 1))) / 2
+              + (n_secondaries * child_height + n_secondaries * spacing) / 2;
             secondary_y = allocation->y + GTK_CONTAINER (box)->border_width;
           }
 
         break;
 
       default:
-        g_assert_not_reached();
+        g_assert_not_reached ();
         break;
     }
 
@@ -775,7 +768,7 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
         {
           child_allocation.width = child_width;
           child_allocation.height = child_height;
@@ -820,5 +813,23 @@ gtk_button_box_size_allocate (GtkWidget     *widget,
     }
 }
 
+/**
+ * gtk_button_box_new:
+ * @orientation: the box' orientation.
+ *
+ * Creates a new #GtkButtonBox.
+ *
+ * Return value: a new #GtkButtonBox.
+ *
+ * Since: 3.0
+ */
+GtkWidget *
+gtk_button_box_new (GtkOrientation orientation)
+{
+  return g_object_new (GTK_TYPE_BUTTON_BOX,
+                       "orientation", orientation,
+                       NULL);
+}
+
 #define __GTK_BUTTON_BOX_C__
 #include "gtkaliasdef.c"
