@@ -283,39 +283,6 @@ gtk_cell_renderer_pixbuf_get_property (GObject        *object,
     }
 }
 
-static void
-unset_image_properties (GtkCellRendererPixbuf *cell)
-{
-  GtkCellRendererPixbufPrivate *priv;
-
-  priv = GTK_CELL_RENDERER_PIXBUF_GET_PRIVATE (cell);
-
-  if (priv->stock_id)
-    {
-      g_free (priv->stock_id);
-      priv->stock_id = NULL;
-      g_object_notify (G_OBJECT (cell), "stock-id");
-    }
-  if (priv->icon_name)
-    {
-      g_free (priv->icon_name);
-      priv->icon_name = NULL;
-      g_object_notify (G_OBJECT (cell), "icon-name");
-    }
-  if (cell->pixbuf)
-    {
-      g_object_unref (cell->pixbuf);
-      cell->pixbuf = NULL;
-      g_object_notify (G_OBJECT (cell), "pixbuf");
-    }
-  if (priv->gicon)
-    {
-      g_object_unref (priv->gicon);
-      priv->gicon = NULL;
-      g_object_notify (G_OBJECT (cell), "gicon");
-    }
-}
-
 static void
 gtk_cell_renderer_pixbuf_set_property (GObject      *object,
 				       guint         param_id,
@@ -330,8 +297,30 @@ gtk_cell_renderer_pixbuf_set_property (GObject      *object,
   switch (param_id)
     {
     case PROP_PIXBUF:
-      unset_image_properties (cellpixbuf);
-      cellpixbuf->pixbuf = (GdkPixbuf *) g_value_dup_object (value);
+      if (cellpixbuf->pixbuf)
+	g_object_unref (cellpixbuf->pixbuf);
+      cellpixbuf->pixbuf = (GdkPixbuf*) g_value_dup_object (value);
+      if (cellpixbuf->pixbuf)
+        {
+          if (priv->stock_id)
+            {
+              g_free (priv->stock_id);
+              priv->stock_id = NULL;
+              g_object_notify (object, "stock-id");
+            }
+          if (priv->icon_name)
+            {
+              g_free (priv->icon_name);
+              priv->icon_name = NULL;
+              g_object_notify (object, "icon-name");
+            }
+          if (priv->gicon)
+            {
+              g_object_unref (priv->gicon);
+              priv->gicon = NULL;
+              g_object_notify (object, "gicon");
+            }
+        }
       break;
     case PROP_PIXBUF_EXPANDER_OPEN:
       if (cellpixbuf->pixbuf_expander_open)
@@ -344,8 +333,38 @@ gtk_cell_renderer_pixbuf_set_property (GObject      *object,
       cellpixbuf->pixbuf_expander_closed = (GdkPixbuf*) g_value_dup_object (value);
       break;
     case PROP_STOCK_ID:
-      unset_image_properties (cellpixbuf);
+      if (priv->stock_id)
+        {
+          if (cellpixbuf->pixbuf)
+            {
+              g_object_unref (cellpixbuf->pixbuf);
+              cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+            }
+          g_free (priv->stock_id);
+        }
       priv->stock_id = g_value_dup_string (value);
+      if (priv->stock_id)
+        {
+          if (cellpixbuf->pixbuf)
+            {
+              g_object_unref (cellpixbuf->pixbuf);
+              cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+            }
+          if (priv->icon_name)
+            {
+              g_free (priv->icon_name);
+              priv->icon_name = NULL;
+              g_object_notify (object, "icon-name");
+            }
+          if (priv->gicon)
+            {
+              g_object_unref (priv->gicon);
+              priv->gicon = NULL;
+              g_object_notify (object, "gicon");
+            }
+        }
       break;
     case PROP_STOCK_SIZE:
       priv->stock_size = g_value_get_uint (value);
@@ -355,15 +374,75 @@ gtk_cell_renderer_pixbuf_set_property (GObject      *object,
       priv->stock_detail = g_value_dup_string (value);
       break;
     case PROP_ICON_NAME:
-      unset_image_properties (cellpixbuf);
+      if (priv->icon_name)
+	{
+	  if (cellpixbuf->pixbuf)
+	    {
+	      g_object_unref (cellpixbuf->pixbuf);
+	      cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+	    }
+	  g_free (priv->icon_name);
+	}
       priv->icon_name = g_value_dup_string (value);
+      if (priv->icon_name)
+        {
+	  if (cellpixbuf->pixbuf)
+	    {
+              g_object_unref (cellpixbuf->pixbuf);
+              cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+	    }
+          if (priv->stock_id)
+            {
+              g_free (priv->stock_id);
+              priv->stock_id = NULL;
+              g_object_notify (object, "stock-id");
+            }
+          if (priv->gicon)
+            {
+              g_object_unref (priv->gicon);
+              priv->gicon = NULL;
+              g_object_notify (object, "gicon");
+            }
+        }
       break;
     case PROP_FOLLOW_STATE:
       priv->follow_state = g_value_get_boolean (value);
       break;
     case PROP_GICON:
-      unset_image_properties (cellpixbuf);
+      if (priv->gicon)
+	{
+	  if (cellpixbuf->pixbuf)
+	    {
+	      g_object_unref (cellpixbuf->pixbuf);
+	      cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+	    }
+	  g_object_unref (priv->gicon);
+	}
       priv->gicon = (GIcon *) g_value_dup_object (value);
+      if (priv->gicon)
+        {
+	  if (cellpixbuf->pixbuf)
+	    {
+              g_object_unref (cellpixbuf->pixbuf);
+              cellpixbuf->pixbuf = NULL;
+              g_object_notify (object, "pixbuf");
+	    }
+          if (priv->stock_id)
+            {
+              g_free (priv->stock_id);
+              priv->stock_id = NULL;
+              g_object_notify (object, "stock-id");
+            }
+          if (priv->icon_name)
+            {
+              g_free (priv->icon_name);
+              priv->icon_name = NULL;
+              g_object_notify (object, "icon-name");
+            }
+        }
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -418,6 +497,7 @@ gtk_cell_renderer_pixbuf_create_themed_pixbuf (GtkCellRendererPixbuf *cellpixbuf
   GtkIconTheme *icon_theme;
   GtkSettings *settings;
   gint width, height;
+  GtkIconInfo *info;
 
   priv = GTK_CELL_RENDERER_PIXBUF_GET_PRIVATE (cellpixbuf);
 
@@ -440,29 +520,106 @@ gtk_cell_renderer_pixbuf_create_themed_pixbuf (GtkCellRendererPixbuf *cellpixbuf
     }
 
   if (priv->icon_name)
-    cellpixbuf->pixbuf = gtk_icon_theme_load_icon (icon_theme,
-			                           priv->icon_name,
-			                           MIN (width, height), 
-                                                   GTK_ICON_LOOKUP_USE_BUILTIN,
-                                                   NULL);
+    info = gtk_icon_theme_lookup_icon (icon_theme,
+                                       priv->icon_name,
+                                       MIN (width, height),
+                                       GTK_ICON_LOOKUP_USE_BUILTIN);
   else if (priv->gicon)
-    {
-      GtkIconInfo *info;
+    info = gtk_icon_theme_lookup_by_gicon (icon_theme,
+                                           priv->gicon,
+                                           MIN (width, height),
+                                           GTK_ICON_LOOKUP_USE_BUILTIN);
+  else
+    info = NULL;
 
-      info = gtk_icon_theme_lookup_by_gicon (icon_theme,
-                                             priv->gicon,
-			                     MIN (width, height), 
-                                             GTK_ICON_LOOKUP_USE_BUILTIN);
-      if (info)
-        {
-          cellpixbuf->pixbuf = gtk_icon_info_load_icon (info, NULL);
-          gtk_icon_info_free (info);
-        }
+  if (info)
+    {
+      GtkStyle *style;
+
+      style = gtk_widget_get_style (GTK_WIDGET (widget));
+      cellpixbuf->pixbuf =
+        gtk_icon_info_load_symbolic_for_style (info,
+                                               style,
+                                               GTK_STATE_NORMAL,
+                                               NULL,
+                                               NULL);
+      gtk_icon_info_free (info);
     }
 
   g_object_notify (G_OBJECT (cellpixbuf), "pixbuf");
 }
 
+static GdkPixbuf *
+create_symbolic_pixbuf (GtkCellRendererPixbuf *cellpixbuf,
+			GtkWidget             *widget,
+			GtkStateType           state)
+{
+  GtkCellRendererPixbufPrivate *priv;
+  GdkScreen *screen;
+  GtkIconTheme *icon_theme;
+  GtkSettings *settings;
+  gint width, height;
+  GtkIconInfo *info;
+  GdkPixbuf *pixbuf;
+
+  priv = GTK_CELL_RENDERER_PIXBUF_GET_PRIVATE (cellpixbuf);
+
+  /* Not a named symbolic icon? */
+  if (priv->icon_name) {
+    if (!g_str_has_suffix (priv->icon_name, "-symbolic"))
+      return NULL;
+  } else if (priv->gicon) {
+    const gchar * const *names;
+    if (!G_IS_THEMED_ICON (priv->gicon))
+      return NULL;
+    names = g_themed_icon_get_names (G_THEMED_ICON (priv->gicon));
+    if (names == NULL || !g_str_has_suffix (names[0], "-symbolic"))
+      return NULL;
+  } else {
+    return NULL;
+  }
+
+  screen = gtk_widget_get_screen (GTK_WIDGET (widget));
+  icon_theme = gtk_icon_theme_get_for_screen (screen);
+  settings = gtk_settings_get_for_screen (screen);
+
+  if (!gtk_icon_size_lookup_for_settings (settings,
+					  priv->stock_size,
+					  &width, &height))
+    {
+      g_warning ("Invalid icon size %u\n", priv->stock_size);
+      width = height = 24;
+    }
+
+
+  if (priv->icon_name)
+    info = gtk_icon_theme_lookup_icon (icon_theme,
+                                       priv->icon_name,
+                                       MIN (width, height),
+                                       GTK_ICON_LOOKUP_USE_BUILTIN);
+  else if (priv->gicon)
+    info = gtk_icon_theme_lookup_by_gicon (icon_theme,
+                                           priv->gicon,
+                                           MIN (width, height),
+                                           GTK_ICON_LOOKUP_USE_BUILTIN);
+  else
+    return NULL;
+
+  if (info)
+    {
+      GtkStyle *style;
+
+      style = gtk_widget_get_style (GTK_WIDGET (widget));
+      pixbuf = gtk_icon_info_load_symbolic_for_style (info,
+                                                      style, state,
+                                                      NULL, NULL);
+      gtk_icon_info_free (info);
+      return pixbuf;
+    }
+
+  return NULL;
+}
+
 static GdkPixbuf *
 create_colorized_pixbuf (GdkPixbuf *src, 
 			 GdkColor  *new_color)
@@ -599,6 +756,7 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
   GdkPixbuf *pixbuf;
   GdkPixbuf *invisible = NULL;
   GdkPixbuf *colorized = NULL;
+  GdkPixbuf *symbolic = NULL;
   GdkRectangle pix_rect;
   GdkRectangle draw_rect;
   cairo_t *cr;
@@ -635,7 +793,7 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
   if (!pixbuf)
     return;
 
-  if (GTK_WIDGET_STATE (widget) == GTK_STATE_INSENSITIVE || !cell->sensitive)
+  if (gtk_widget_get_state (widget) == GTK_STATE_INSENSITIVE || !cell->sensitive)
     {
       GtkIconSource *source;
       
@@ -668,7 +826,7 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
 
       if ((flags & GTK_CELL_RENDERER_SELECTED) != 0)
 	{
-	  if (GTK_WIDGET_HAS_FOCUS (widget))
+	  if (gtk_widget_has_focus (widget))
 	    state = GTK_STATE_SELECTED;
 	  else
 	    state = GTK_STATE_ACTIVE;
@@ -676,10 +834,15 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
       else
 	state = GTK_STATE_PRELIGHT;
 
-      colorized = create_colorized_pixbuf (pixbuf,
-					   &widget->style->base[state]);
+      symbolic = create_symbolic_pixbuf (cellpixbuf, widget, state);
+      if (!symbolic) {
+        colorized = create_colorized_pixbuf (pixbuf,
+					     &widget->style->base[state]);
 
-      pixbuf = colorized;
+	pixbuf = colorized;
+      } else {
+        pixbuf = symbolic;
+      }
     }
 
   cr = gdk_cairo_create (window);
@@ -695,6 +858,9 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
 
   if (colorized)
     g_object_unref (colorized);
+
+  if (symbolic)
+    g_object_unref (symbolic);
 }
 
 #define __GTK_CELL_RENDERER_PIXBUF_C__
