@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkfilechooserprivate.h"
 
 #include "gtkfilechooserwidget.h"
@@ -49,7 +49,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkFileChooserWidget, gtk_file_chooser_widget, GTK_TYPE
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_FILE_CHOOSER,
 						_gtk_file_chooser_delegate_iface_init)
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_FILE_CHOOSER_EMBED,
-						_gtk_file_chooser_embed_delegate_iface_init));
+						_gtk_file_chooser_embed_delegate_iface_init))
 
 static void
 gtk_file_chooser_widget_class_init (GtkFileChooserWidgetClass *class)
@@ -100,7 +100,7 @@ gtk_file_chooser_widget_constructor (GType                  type,
 
   gtk_widget_push_composite_child ();
 
-  priv->impl = _gtk_file_chooser_default_new (priv->file_system);
+  priv->impl = _gtk_file_chooser_default_new ();
   
   gtk_box_pack_start (GTK_BOX (object), priv->impl, TRUE, TRUE, 0);
   gtk_widget_show (priv->impl);
@@ -126,10 +126,6 @@ gtk_file_chooser_widget_set_property (GObject         *object,
 
   switch (prop_id)
     {
-    case GTK_FILE_CHOOSER_PROP_FILE_SYSTEM_BACKEND:
-      g_free (priv->file_system);
-      priv->file_system = g_value_dup_string (value);
-      break;
     default:
       g_object_set_property (G_OBJECT (priv->impl), pspec->name, value);
       break;
@@ -167,30 +163,5 @@ gtk_file_chooser_widget_new (GtkFileChooserAction action)
 		       NULL);
 }
 
-/**
- * gtk_file_chooser_widget_new_with_backend:
- * @action: Open or save mode for the widget
- * @backend: The name of the specific filesystem backend to use.
- * 
- * Creates a new #GtkFileChooserWidget with a specified backend.  This is
- * especially useful if you use gtk_file_chooser_set_local_only() to allow
- * non-local files.  This is a file chooser widget that can be embedded in
- * custom windows and it is the same widget that is used by
- * #GtkFileChooserDialog.
- * 
- * Return value: a new #GtkFileChooserWidget
- *
- * Since: 2.4
- **/
-GtkWidget *
-gtk_file_chooser_widget_new_with_backend (GtkFileChooserAction  action,
-					  const gchar          *backend)
-{
-  return g_object_new (GTK_TYPE_FILE_CHOOSER_WIDGET,
-		       "action", action,
-		       "file-system-backend", backend,
-		       NULL);
-}
-
 #define __GTK_FILE_CHOOSER_WIDGET_C__
 #include "gtkaliasdef.c"
