@@ -21,21 +21,21 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#ifndef __GTK_MENU_IMAGE_ITEM_H__
-#define __GTK_MENU_IMAGE_ITEM_H__
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
+#ifndef __GTK_IMAGE_MENU_ITEM_H__
+#define __GTK_IMAGE_MENU_ITEM_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkmenuitem.h>
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 #define GTK_TYPE_IMAGE_MENU_ITEM            (gtk_image_menu_item_get_type ())
 #define GTK_IMAGE_MENU_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_IMAGE_MENU_ITEM, GtkImageMenuItem))
@@ -53,7 +53,8 @@ struct _GtkImageMenuItem
   GtkMenuItem menu_item;
 
   /*< private >*/
-  GtkWidget *image;
+  GtkWidget      *GSEAL (image);
+
 };
 
 struct _GtkImageMenuItemClass
@@ -68,14 +69,18 @@ GtkWidget* gtk_image_menu_item_new_with_label    (const gchar      *label);
 GtkWidget* gtk_image_menu_item_new_with_mnemonic (const gchar      *label);
 GtkWidget* gtk_image_menu_item_new_from_stock    (const gchar      *stock_id,
                                                   GtkAccelGroup    *accel_group);
+void       gtk_image_menu_item_set_always_show_image (GtkImageMenuItem *image_menu_item,
+                                                      gboolean          always_show);
+gboolean   gtk_image_menu_item_get_always_show_image (GtkImageMenuItem *image_menu_item);
 void       gtk_image_menu_item_set_image         (GtkImageMenuItem *image_menu_item,
                                                   GtkWidget        *image);
 GtkWidget* gtk_image_menu_item_get_image         (GtkImageMenuItem *image_menu_item);
+void       gtk_image_menu_item_set_use_stock     (GtkImageMenuItem *image_menu_item,
+						  gboolean          use_stock);
+gboolean   gtk_image_menu_item_get_use_stock     (GtkImageMenuItem *image_menu_item);
+void       gtk_image_menu_item_set_accel_group   (GtkImageMenuItem *image_menu_item, 
+						  GtkAccelGroup    *accel_group);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __GTK_IMAGE_MENU_ITEM_H__ */
