@@ -33,6 +33,17 @@
 #include "gtkalias.h"
 
 
+/**
+ * SECTION:gtkseparator
+ * @Short_description: Base class for GtkHSeparator and GtkVSeparator
+ * @Title: GtkSeparator
+ *
+ * The GtkSeparator widget is the base class for #GtkHSeparator and
+ * #GtkVSeparator. It can be used in the same way as these, by setting
+ * the "orientation" property suitably.
+ */
+
+
 enum {
   PROP_0,
   PROP_ORIENTATION
@@ -64,9 +75,9 @@ static gboolean   gtk_separator_expose       (GtkWidget      *widget,
                                               GdkEventExpose *event);
 
 
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GtkSeparator, gtk_separator, GTK_TYPE_WIDGET,
-                                  G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE,
-                                                         NULL))
+G_DEFINE_TYPE_WITH_CODE (GtkSeparator, gtk_separator, GTK_TYPE_WIDGET,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE,
+                                                NULL))
 
 
 static void
@@ -94,7 +105,7 @@ gtk_separator_init (GtkSeparator *separator)
   GtkWidget *widget = GTK_WIDGET (separator);
   GtkSeparatorPrivate *private = GTK_SEPARATOR_GET_PRIVATE (separator);
 
-  GTK_WIDGET_SET_FLAGS (separator, GTK_NO_WINDOW);
+  gtk_widget_set_has_window (GTK_WIDGET (separator), FALSE);
 
   private->orientation = GTK_ORIENTATION_HORIZONTAL;
 
@@ -184,7 +195,7 @@ gtk_separator_expose (GtkWidget      *widget,
   gint     separator_width;
   gint     separator_height;
 
-  if (!GTK_WIDGET_DRAWABLE (widget))
+  if (!gtk_widget_is_drawable (widget))
     return FALSE;
 
   gtk_widget_style_get (widget,
@@ -197,7 +208,7 @@ gtk_separator_expose (GtkWidget      *widget,
     {
       if (wide_separators)
         gtk_paint_box (widget->style, widget->window,
-                       GTK_WIDGET_STATE (widget), GTK_SHADOW_ETCHED_OUT,
+                       gtk_widget_get_state (widget), GTK_SHADOW_ETCHED_OUT,
                        &event->area, widget, "hseparator",
                        widget->allocation.x,
                        widget->allocation.y + (widget->allocation.height -
@@ -206,7 +217,7 @@ gtk_separator_expose (GtkWidget      *widget,
                        separator_height);
       else
         gtk_paint_hline (widget->style, widget->window,
-                         GTK_WIDGET_STATE (widget),
+                         gtk_widget_get_state (widget),
                          &event->area, widget, "hseparator",
                          widget->allocation.x,
                          widget->allocation.x + widget->allocation.width - 1,
@@ -217,7 +228,7 @@ gtk_separator_expose (GtkWidget      *widget,
     {
       if (wide_separators)
         gtk_paint_box (widget->style, widget->window,
-                       GTK_WIDGET_STATE (widget), GTK_SHADOW_ETCHED_OUT,
+                       gtk_widget_get_state (widget), GTK_SHADOW_ETCHED_OUT,
                        &event->area, widget, "vseparator",
                        widget->allocation.x + (widget->allocation.width -
                                                separator_width) / 2,
@@ -226,7 +237,7 @@ gtk_separator_expose (GtkWidget      *widget,
                        widget->allocation.height);
       else
         gtk_paint_vline (widget->style, widget->window,
-                         GTK_WIDGET_STATE (widget),
+                         gtk_widget_get_state (widget),
                          &event->area, widget, "vseparator",
                          widget->allocation.y,
                          widget->allocation.y + widget->allocation.height - 1,
@@ -237,7 +248,6 @@ gtk_separator_expose (GtkWidget      *widget,
   return FALSE;
 }
 
-#if 0
 /**
  * gtk_separator_new:
  * @orientation: the separator's orientation.
@@ -246,7 +256,7 @@ gtk_separator_expose (GtkWidget      *widget,
  *
  * Return value: a new #GtkSeparator.
  *
- * Since: 2.16
+ * Since: 3.0
  **/
 GtkWidget *
 gtk_separator_new (GtkOrientation orientation)
@@ -255,7 +265,6 @@ gtk_separator_new (GtkOrientation orientation)
                        "orientation", orientation,
                        NULL);
 }
-#endif
 
 
 #define __GTK_SEPARATOR_C__
