@@ -21,9 +21,13 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_TEXT_TAG_TABLE_H__
 #define __GTK_TEXT_TAG_TABLE_H__
 
@@ -31,8 +35,6 @@
 
 G_BEGIN_DECLS
 
-#include <gtk/gtktexttag.h>
-
 typedef void (* GtkTextTagTableForeach) (GtkTextTag *tag, gpointer data);
 
 #define GTK_TYPE_TEXT_TAG_TABLE            (gtk_text_tag_table_get_type ())
@@ -48,11 +50,11 @@ struct _GtkTextTagTable
 {
   GObject parent_instance;
 
-  GHashTable *hash;
-  GSList *anonymous;
-  gint anon_count;
+  GHashTable *GSEAL (hash);
+  GSList *GSEAL (anonymous);
+  gint GSEAL (anon_count);
 
-  GSList *buffers;
+  GSList *GSEAL (buffers);
 };
 
 struct _GtkTextTagTableClass
