@@ -622,6 +622,31 @@ gtk_tree_path_get_indices (GtkTreePath *path)
   return path->indices;
 }
 
+/**
+ * gtk_tree_path_get_indices_with_depth:
+ * @path: A #GtkTreePath.
+ * @depth: Number of elements returned in the integer array
+ *
+ * Returns the current indices of @path.
+ * This is an array of integers, each representing a node in a tree.
+ * It also returns the number of elements in the array.
+ * The array should not be freed.
+ *
+ * Return value: (array length=depth): The current indices, or %NULL.
+ *
+ * Since: 3.0
+ **/
+gint *
+gtk_tree_path_get_indices_with_depth (GtkTreePath *path, gint *depth)
+{
+  g_return_val_if_fail (path != NULL, NULL);
+
+  if (depth)
+    *depth = path->depth;
+
+  return path->indices;
+}
+
 /**
  * gtk_tree_path_free:
  * @path: A #GtkTreePath.
@@ -953,7 +978,7 @@ gtk_tree_model_get_n_columns (GtkTreeModel *tree_model)
  *
  * Returns the type of the column.
  *
- * Return value: The type of the column.
+ * Return value: (transfer none): The type of the column.
  **/
 GType
 gtk_tree_model_get_column_type (GtkTreeModel *tree_model,
@@ -1123,7 +1148,7 @@ gtk_tree_model_get_path (GtkTreeModel *tree_model,
  * @tree_model: A #GtkTreeModel.
  * @iter: The #GtkTreeIter.
  * @column: The column to lookup the value at.
- * @value: An empty #GValue to set.
+ * @value: (out) (transfer none) An empty #GValue to set.
  *
  * Initializes and sets @value to that at @column.
  * When done with @value, g_value_unset() needs to be called 
@@ -2034,7 +2059,7 @@ gtk_tree_row_reference_get_model (GtkTreeRowReference *reference)
 
 /**
  * gtk_tree_row_reference_valid:
- * @reference: A #GtkTreeRowReference, or %NULL
+ * @reference: (allow-none): A #GtkTreeRowReference, or %NULL
  * 
  * Returns %TRUE if the @reference is non-%NULL and refers to a current valid
  * path.
@@ -2071,7 +2096,7 @@ gtk_tree_row_reference_copy (GtkTreeRowReference *reference)
 
 /**
  * gtk_tree_row_reference_free:
- * @reference: A #GtkTreeRowReference, or %NULL
+ * @reference: (allow-none): A #GtkTreeRowReference, or %NULL
  * 
  * Free's @reference. @reference may be %NULL.
  **/
