@@ -245,12 +245,10 @@ struct _GtkTreeViewPrivate
 
   /* Grid and tree lines */
   GtkTreeViewGridLines grid_lines;
-  double grid_line_dashes[2];
-  int grid_line_width;
+  GdkGC *grid_line_gc;
 
   gboolean tree_lines_enabled;
-  double tree_line_dashes[2];
-  int tree_line_width;
+  GdkGC *tree_line_gc;
 
   /* Row separators */
   GtkTreeViewRowSeparatorFunc row_separator_func;
@@ -408,7 +406,8 @@ void _gtk_tree_view_column_unset_tree_view  (GtkTreeViewColumn *column);
 void _gtk_tree_view_column_set_width        (GtkTreeViewColumn *column,
 					     gint               width);
 void _gtk_tree_view_column_start_drag       (GtkTreeView       *tree_view,
-					     GtkTreeViewColumn *column);
+					     GtkTreeViewColumn *column,
+                                             GdkDevice         *device);
 gboolean _gtk_tree_view_column_cell_event   (GtkTreeViewColumn  *tree_column,
 					     GtkCellEditable   **editable_widget,
 					     GdkEvent           *event,
