@@ -161,6 +161,8 @@ GType gtk_tree_view_grid_lines_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_TREE_VIEW_GRID_LINES (gtk_tree_view_grid_lines_get_type ())
 GType gtk_drag_result_get_type (void) G_GNUC_CONST;
 #define GTK_TYPE_DRAG_RESULT (gtk_drag_result_get_type ())
+GType gtk_size_request_mode_get_type (void) G_GNUC_CONST;
+#define GTK_TYPE_SIZE_REQUEST_MODE (gtk_size_request_mode_get_type ())
 
 /* enumerations from "gtkfilechooser.h" */
 GType gtk_file_chooser_action_get_type (void) G_GNUC_CONST;
