@@ -34,7 +34,6 @@
 *tp++ = gdk_gravity_get_type();
 *tp++ = gdk_image_get_type();
 *tp++ = gdk_image_type_get_type();
-*tp++ = gdk_input_condition_get_type();
 *tp++ = gdk_input_mode_get_type();
 *tp++ = gdk_input_source_get_type();
 *tp++ = gdk_interp_type_get_type();
@@ -90,6 +89,7 @@
 *tp++ = gtk_adjustment_get_type();
 *tp++ = gtk_alignment_get_type();
 *tp++ = gtk_anchor_type_get_type();
+*tp++ = gtk_application_get_type();
 *tp++ = gtk_arrow_get_type();
 *tp++ = gtk_arrow_placement_get_type();
 *tp++ = gtk_arrow_type_get_type();
@@ -150,7 +150,6 @@
 *tp++ = gtk_event_box_get_type();
 *tp++ = gtk_expander_get_type();
 *tp++ = gtk_expander_style_get_type();
-*tp++ = gtk_extended_layout_get_type();
 *tp++ = gtk_file_chooser_action_get_type();
 *tp++ = gtk_file_chooser_button_get_type();
 *tp++ = gtk_file_chooser_confirmation_get_type();
@@ -247,7 +246,6 @@
 *tp++ = gtk_private_flags_get_type();
 *tp++ = gtk_progress_bar_get_type();
 *tp++ = gtk_progress_bar_orientation_get_type();
-*tp++ = gtk_progress_bar_style_get_type();
 *tp++ = gtk_radio_action_get_type();
 *tp++ = gtk_radio_button_get_type();
 *tp++ = gtk_radio_menu_item_get_type();
@@ -289,6 +287,8 @@
 *tp++ = gtk_shadow_type_get_type();
 *tp++ = gtk_size_group_get_type();
 *tp++ = gtk_size_group_mode_get_type();
+*tp++ = gtk_size_request_get_type();
+*tp++ = gtk_size_request_mode_get_type();
 *tp++ = gtk_socket_get_type();
 *tp++ = gtk_sort_type_get_type();
 *tp++ = gtk_spin_button_get_type();
