@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -32,7 +32,6 @@
 #define __GTK_VSCALE_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkscale.h>
 
 
@@ -50,6 +49,12 @@ G_BEGIN_DECLS
 typedef struct _GtkVScale       GtkVScale;
 typedef struct _GtkVScaleClass  GtkVScaleClass;
 
+/**
+ * GtkVScale:
+ *
+ * The #GtkVScale struct contains private data only, and
+ * should be accessed using the functions below.
+ */
 struct _GtkVScale
 {
   GtkScale scale;
