@@ -378,6 +378,7 @@ void     gtk_window_get_position     (GtkWindow   *window,
 gboolean gtk_window_parse_geometry   (GtkWindow   *window,
                                       const gchar *geometry);
 GtkWindowGroup *gtk_window_get_group (GtkWindow   *window);
+gboolean gtk_window_has_group        (GtkWindow   *window);
 
 /* Ignore this unless you are writing a GUI builder */
 void     gtk_window_reshow_with_initial_size (GtkWindow *window);
@@ -414,7 +415,7 @@ void            _gtk_window_constrain_size     (GtkWindow *window,
 						gint       height,
 						gint      *new_width,
 						gint      *new_height);
-GtkWidget      *_gtk_window_group_get_current_grab (GtkWindowGroup *window_group);
+GtkWidget      *gtk_window_group_get_current_grab (GtkWindowGroup *window_group);
 void            _gtk_window_group_add_device_grab    (GtkWindowGroup   *window_group,
                                                       GtkWidget        *widget,
                                                       GdkDevice        *device,
