@@ -19,8 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#undef GTK_DISABLE_DEPRECATED
-#include <config.h>
+#include "config.h"
 #include <gtk/gtk.h>
 #include "prop-editor.h"
 
@@ -56,7 +55,7 @@ change_orientation (GtkWidget *button, GtkWidget *toolbar)
 
   g_object_ref (toolbar);
   gtk_container_remove (GTK_CONTAINER (table), toolbar);
-  gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar), orientation);
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (toolbar), orientation);
   if (orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       gtk_table_attach (GTK_TABLE (table), toolbar,
@@ -87,7 +86,7 @@ set_toolbar_style_toggled (GtkCheckButton *button, GtkToolbar *toolbar)
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     {
-      style = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+      style = gtk_combo_box_get_active (GTK_COMBO_BOX (option_menu));
 
       gtk_toolbar_set_style (toolbar, style);
       gtk_widget_set_sensitive (option_menu, TRUE);
@@ -104,7 +103,7 @@ change_toolbar_style (GtkWidget *option_menu, GtkWidget *toolbar)
 {
   GtkToolbarStyle style;
 
-  style = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+  style = gtk_combo_box_get_active (GTK_COMBO_BOX (option_menu));
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), style);
 }
 
@@ -322,8 +321,10 @@ set_icon_size_toggled (GtkCheckButton *button, GtkToolbar *toolbar)
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     {
-      icon_size = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
-      icon_size += GTK_ICON_SIZE_SMALL_TOOLBAR;
+      if (gtk_combo_box_get_active (GTK_COMBO_BOX (option_menu)) == 0)
+        icon_size = GTK_ICON_SIZE_SMALL_TOOLBAR;
+      else
+        icon_size = GTK_ICON_SIZE_LARGE_TOOLBAR;
 
       gtk_toolbar_set_icon_size (toolbar, icon_size);
       gtk_widget_set_sensitive (option_menu, TRUE);
@@ -336,12 +337,14 @@ set_icon_size_toggled (GtkCheckButton *button, GtkToolbar *toolbar)
 }
 
 static void
-icon_size_history_changed (GtkOptionMenu *menu, GtkToolbar *toolbar)
+icon_size_history_changed (GtkComboBox *menu, GtkToolbar *toolbar)
 {
   int icon_size;
 
-  icon_size = gtk_option_menu_get_history (menu);
-  icon_size += GTK_ICON_SIZE_SMALL_TOOLBAR;
+  if (gtk_combo_box_get_active (menu) == 0)
+    icon_size = GTK_ICON_SIZE_SMALL_TOOLBAR;
+  else
+    icon_size = GTK_ICON_SIZE_LARGE_TOOLBAR;
 
   gtk_toolbar_set_icon_size (toolbar, icon_size);
 }
@@ -449,7 +452,7 @@ toolbar_drag_motion (GtkToolbar     *toolbar,
   if (!drag_item)
     {
       drag_item = gtk_tool_button_new (NULL, "A quite long button");
-      gtk_object_sink (GTK_OBJECT (g_object_ref (drag_item)));
+      g_object_ref_sink (g_object_ref (drag_item));
     }
   
   gdk_drag_status (context, GDK_ACTION_MOVE, time);
@@ -511,6 +514,7 @@ main (gint argc, gchar **argv)
   GtkWidget *menuitem;
   GtkWidget *button;
   GtkWidget *label;
+  GIcon *gicon;
   GSList *group;
   
   gtk_init (&argc, &argv);
@@ -551,21 +555,13 @@ main (gint argc, gchar **argv)
   g_signal_connect (checkbox, "toggled", G_CALLBACK (set_toolbar_style_toggled), toolbar);
   gtk_box_pack_start (GTK_BOX (hbox1), checkbox, FALSE, FALSE, 0);
   
-  option_menu = gtk_option_menu_new();
+  option_menu = gtk_combo_box_new_text ();
   gtk_widget_set_sensitive (option_menu, FALSE);  
   g_object_set_data (G_OBJECT (checkbox), "option-menu", option_menu);
   
-  menu = gtk_menu_new();
   for (i = 0; i < G_N_ELEMENTS (toolbar_styles); i++)
-    {
-      GtkWidget *menuitem;
-
-      menuitem = gtk_menu_item_new_with_label (toolbar_styles[i]);
-      gtk_container_add (GTK_CONTAINER (menu), menuitem);
-      gtk_widget_show (menuitem);
-    }
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu),
+    gtk_combo_box_append_text (GTK_COMBO_BOX (option_menu), toolbar_styles[i]);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (option_menu),
 			       GTK_TOOLBAR (toolbar)->style);
   gtk_box_pack_start (GTK_BOX (hbox2), option_menu, FALSE, FALSE, 0);
   g_signal_connect (option_menu, "changed",
@@ -575,21 +571,12 @@ main (gint argc, gchar **argv)
   g_signal_connect (checkbox, "toggled", G_CALLBACK (set_icon_size_toggled), toolbar);
   gtk_box_pack_start (GTK_BOX (hbox2), checkbox, FALSE, FALSE, 0);
 
-  option_menu = gtk_option_menu_new();
+  option_menu = gtk_combo_box_new_text ();
   g_object_set_data (G_OBJECT (checkbox), "option-menu", option_menu);
   gtk_widget_set_sensitive (option_menu, FALSE);
-  menu = gtk_menu_new();
-  menuitem = gtk_menu_item_new_with_label ("small toolbar");
-  g_object_set_data (G_OBJECT (menuitem), "value-id", GINT_TO_POINTER (GTK_ICON_SIZE_SMALL_TOOLBAR));
-  gtk_container_add (GTK_CONTAINER (menu), menuitem);
-  gtk_widget_show (menuitem);
+  gtk_combo_box_append_text (GTK_COMBO_BOX (option_menu), "small toolbar");
+  gtk_combo_box_append_text (GTK_COMBO_BOX (option_menu), "large toolbar");
 
-  menuitem = gtk_menu_item_new_with_label ("large toolbar");
-  g_object_set_data (G_OBJECT (menuitem), "value-id", GINT_TO_POINTER (GTK_ICON_SIZE_LARGE_TOOLBAR));
-  gtk_container_add (GTK_CONTAINER (menu), menuitem);
-  gtk_widget_show (menuitem);
-
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
   gtk_box_pack_start (GTK_BOX (hbox2), option_menu, FALSE, FALSE, 0);
   g_signal_connect (option_menu, "changed",
 		    G_CALLBACK (icon_size_history_changed), toolbar);
@@ -608,7 +595,7 @@ main (gint argc, gchar **argv)
   gtk_tool_button_set_label (GTK_TOOL_BUTTON (item), NULL);
   add_item_to_list (store, item, "New");
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
-  g_timeout_add (3000, (GSourceFunc) timeout_cb, item);
+  gdk_threads_add_timeout (3000, (GSourceFunc) timeout_cb, item);
   gtk_tool_item_set_expand (item, TRUE);
 
   menu = gtk_menu_new ();
@@ -626,7 +613,7 @@ main (gint argc, gchar **argv)
   gtk_menu_tool_button_set_menu (GTK_MENU_TOOL_BUTTON (item), menu);
   add_item_to_list (store, item, "Open");
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
-  g_timeout_add (3000, (GSourceFunc) timeout_cb1, item);
+  gdk_threads_add_timeout (3000, (GSourceFunc) timeout_cb1, item);
  
   menu = gtk_menu_new ();
   for (i = 0; i < 20; i++)
@@ -706,7 +693,19 @@ main (gint argc, gchar **argv)
   add_item_to_list (store, item, "Apple");
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
   gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (item), TRUE);
-  
+
+  gicon = g_content_type_get_icon ("video/ogg");
+  image = gtk_image_new_from_gicon (gicon, GTK_ICON_SIZE_LARGE_TOOLBAR);
+  g_object_unref (gicon);
+  item = gtk_tool_button_new (image, "Video");
+  add_item_to_list (store, item, "Video");
+  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
+
+  image = gtk_image_new_from_icon_name ("utility-terminal", GTK_ICON_SIZE_LARGE_TOOLBAR);
+  item = gtk_tool_button_new (image, "Terminal");
+  add_item_to_list (store, item, "Terminal");
+  gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
+
   hbox = gtk_hbox_new (FALSE, 5);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   gtk_table_attach (GTK_TABLE (table), hbox,
